@@ -30,6 +30,7 @@
 #include <GTLCore/Region.h>
 #include <GTLCore/Debug.h>
 #include <GTLCore/PixelDescription.h>
+#include <GTLCore/ColorConverters.h>
 
 STATIC_INITIALISATION( PngDC )
 {
@@ -115,21 +116,46 @@ GTLCore::AbstractImage* PngDC::decode( const GTLCore::String& _fileName, GTLCore
   GTL_ASSERT( channelType );
   int channelsCount = 0;
   int alphaPos = -1;
+  const GTLCore::AbstractColorConverter* converter = 0;
   switch( color_type )
   {
     case PNG_COLOR_TYPE_GRAY:
       channelsCount = 1;
+      if(channelType == GTLCore::Type::UnsignedInteger8)
+      {
+          converter = GTLCore::ColorConverters::instance()->sGrayU8();
+      } else {
+          converter = GTLCore::ColorConverters::instance()->sGrayU16();
+      }
       break;
     case PNG_COLOR_TYPE_GRAY_ALPHA:
       channelsCount = 2;
       alphaPos = 1;
+      if(channelType == GTLCore::Type::UnsignedInteger8)
+      {
+          converter = GTLCore::ColorConverters::instance()->sGrayaU8();
+      } else {
+          converter = GTLCore::ColorConverters::instance()->sGrayaU16();
+      }
       break;
     case PNG_COLOR_TYPE_RGB:
       channelsCount = 3;
+      if(channelType == GTLCore::Type::UnsignedInteger8)
+      {
+          converter = GTLCore::ColorConverters::instance()->sRgbU8();
+      } else {
+          converter = GTLCore::ColorConverters::instance()->sRgbU16();
+      }
       break;
     case PNG_COLOR_TYPE_RGB_ALPHA:
       channelsCount = 4;
       alphaPos = 3;
+      if(channelType == GTLCore::Type::UnsignedInteger8)
+      {
+          converter = GTLCore::ColorConverters::instance()->sRgbaU8();
+      } else {
+          converter = GTLCore::ColorConverters::instance()->sRgbaU16();
+      }
       break;
     default:
       png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
@@ -138,9 +164,9 @@ GTLCore::AbstractImage* PngDC::decode( const GTLCore::String& _fileName, GTLCore
   }
   GTL_ASSERT( channelsCount != 0);
   GTLCore::PixelDescription pixelDescription( channelType, channelsCount, alphaPos );
-  
+  GTL_ASSERT(converter);
   // Allocate buffer image
-  GTLCore::Image* image = new GTLCore::Image( width, height, pixelDescription );
+  GTLCore::Image* image = new GTLCore::Image( width, height, pixelDescription, converter );
   if( _region )
   {
     _region->setCols( width );
