@@ -23,7 +23,14 @@
 #include "Module.h"
 
 // LLVM
+#include <llvm/Support/MutexGuard.h>
+#ifdef LLVM_27_OR_28
 #include <llvm/System/Path.h>
+#include <llvm/System/Mutex.h>
+#else
+#include <llvm/Support/Path.h>
+#include <llvm/Support/Mutex.h>
+#endif
 
 #include <GTLCore/Macros_p.h>
 
@@ -35,6 +42,7 @@ using namespace OpenCTL;
 struct ModulesManager::Private {
   std::map<GTLCore::String, Module*> modules;
   std::list<GTLCore::String> directories;
+  llvm::sys::Mutex mutex;
 };
 
 STATIC_POINTER(ModulesManager, s_instance);
@@ -66,6 +74,7 @@ Module* ModulesManager::module(const GTLCore::String& name)
 
 Module* ModulesManager::loadModule(const GTLCore::String& name)
 {
+  llvm::MutexGuard mg(d->mutex);
   Module* m = module( name );
   if( m )
   { // The module is already loaded and in the registry, return it
@@ -92,6 +101,7 @@ Module* ModulesManager::loadModule(const GTLCore::String& name)
 
 void ModulesManager::registerModule(const GTLCore::String& name, Module* m )
 {
+  llvm::MutexGuard mg(d->mutex);
   d->modules[ name ] = m;
 }
 
