@@ -33,7 +33,11 @@
 #include <llvm/Module.h>
 // #include <llvm/Transforms/Utils/Cloning.h>
 // Library Loader
+#ifdef LLVM_27_OR_28
 #include <llvm/System/DynamicLibrary.h>
+#else
+#include <llvm/Support/DynamicLibrary.h>
+#endif
 // Passes
 #include <llvm/PassManager.h>
 
