@@ -50,12 +50,14 @@ using namespace OpenCTL;
 struct ParserNG::Private {
   Compiler* compiler;
   AST::Tree* tree;
+  bool parsingStarted;
 };
 
 ParserNG::ParserNG(Compiler* _compiler, LexerNG* _lexer) : ParserBase(_compiler, _lexer), d(new Private)
 {
   d->compiler = _compiler;
-  d->tree = 0;
+  d->tree = new AST::Tree;
+  d->parsingStarted = false;
 }
 
 ParserNG::~ParserNG()
@@ -66,8 +68,10 @@ ParserNG::~ParserNG()
 AST::Tree* ParserNG::parse()
 {
   OCTL_DEBUG("Parsing with ParserNG");
-  OCTL_ASSERT( not d->tree );
-  d->tree = new AST::Tree;
+  OCTL_ASSERT( d->tree );
+  OCTL_ASSERT( not d->parsingStarted );
+
+  d->parsingStarted = true;
   variablesManager()->startContext();
   // parse module header
   parseModuleHeader();
