@@ -22,6 +22,7 @@
 #include <cstring>
 
 #include "GTLCore/FloatHalfConverter_p.h"
+#include "GTLCore/ProgressReport.h"
 
 class TestInteger8GrayScaleProgram : public GTLTest::Case {
   public:
@@ -118,7 +119,7 @@ void testCall(float a, output float b) \n\
 }");
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
-      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float, 1));
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float32, 1));
       GTLTEST_CHECK_REQUIRED(Program.isInitialised());
       GTLCore::Array arr( 4 * sizeof(float));
       arr.data<float>()[0] = 10;
@@ -264,7 +265,7 @@ void testCall(half rIn, half gIn, half bIn, output half rOut, output half gOut,
 }");
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
-      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Half, 3));
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float16, 3));
       GTLTEST_CHECK_REQUIRED(Program.isInitialised());
       GTLCore::Array arr( 6 * sizeof(GTLCore::half));
       arr.data<GTLCore::half>()[0] = float2half( 10 );
@@ -314,7 +315,7 @@ void testCall(float rIn, float gIn, float bIn, output float rOut, output float g
 }");
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
-      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float, 3));
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float32, 3));
       GTLTEST_CHECK_REQUIRED(Program.isInitialised());
       GTLCore::Array arr( 6 * sizeof(float));
       arr.data<float>()[0] = 10;
@@ -372,7 +373,7 @@ void testCall(float rIn, int gIn, int bIn, output float rOut, output int gOut, o
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
       std::vector<const GTLCore::Type*> types;
-      types.push_back( GTLCore::Type::Float );
+      types.push_back( GTLCore::Type::Float32 );
       types.push_back( GTLCore::Type::Integer32 );
       types.push_back( GTLCore::Type::Integer8 );
       OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( types ));
@@ -473,7 +474,7 @@ class TestRgb32Float8ToRgb8Program : public GTLTest::Case {
     }");
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
-      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float, 3), GTLCore::PixelDescription( GTLCore::Type::Integer8, 3));
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float32, 3), GTLCore::PixelDescription( GTLCore::Type::Integer8, 3));
       GTLTEST_CHECK_REQUIRED(Program.isInitialised());
       GTLCore::Array src( 2 * sizeof(float) * 3);
       *((float*)(src.rawData())) = 10;
@@ -515,10 +516,10 @@ class TestRgb32FloatExposureProgram : public GTLTest::Case {
     }");
       p.compile();
       GTLTEST_CHECK_REQUIRED(p.isCompiled());
-      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float, 3));
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float32, 3));
       GTLTEST_CHECK_REQUIRED(Program.isInitialised());
-      GTLTEST_CHECK_EQUAL(Program.varying( "exposure" ).type(), GTLCore::Type::Float);
-      GTLTEST_CHECK_NEAR_EQUAL( Program.varying( "exposure" ).asFloat(), 1.5);
+      GTLTEST_CHECK_EQUAL(Program.varying( "exposure" ).type(), GTLCore::Type::Float32);
+      GTLTEST_CHECK_NEAR_EQUAL( Program.varying( "exposure" ).asFloat32(), 1.5);
       GTLTEST_CHECK_EQUAL(Program.varyings().size(), 1);
       GTLTEST_CHECK_EQUAL(*Program.varyings().begin(), "exposure");
       GTLCore::Array src( 2 * sizeof(float) * 3);
@@ -543,8 +544,8 @@ class TestRgb32FloatExposureProgram : public GTLTest::Case {
       GTLTEST_CHECK_EQUAL( *((float*)(dst.rawData()+16)), 75);
       GTLTEST_CHECK_EQUAL( *((float*)(dst.rawData()+20)), 90);
       Program.setVarying( "exposure", 2 );
-      GTLTEST_CHECK_EQUAL(Program.varying( "exposure" ).type(), GTLCore::Type::Float);
-      GTLTEST_CHECK_NEAR_EQUAL( Program.varying( "exposure" ).asFloat(), 2.0);
+      GTLTEST_CHECK_EQUAL(Program.varying( "exposure" ).type(), GTLCore::Type::Float32);
+      GTLTEST_CHECK_NEAR_EQUAL( Program.varying( "exposure" ).asFloat32(), 2.0);
       Program.apply(src, dst);
       GTLTEST_CHECK_EQUAL( *((float*)(dst.rawData())), 20);
       GTLTEST_CHECK_EQUAL( *((float*)(dst.rawData()+4)), 40);
@@ -634,6 +635,86 @@ class TestMultiDifferentInputsProgram : public GTLTest::Case {
     }
 };
 
+class TestProgressReport : public GTLCore::ProgressReport {
+  public:
+    TestProgressReport() : row(0), pixel(0) {}
+    virtual ~TestProgressReport() {}
+    virtual void nextRow() {
+      ++row;
+    }
+    virtual void nextPixel() {
+      ++pixel;
+    }
+    virtual bool interrupted() const {
+      return false;
+    }
+    int row, pixel;
+  
+};
+
+class TestProgressReportProgram : public GTLTest::Case {
+  public:
+    TestProgressReportProgram() : GTLTest::Case("ProgressReportProgram") {}
+    virtual void runTest()
+    {
+      TestProgressReport report;
+      OpenCTL::Module p;
+      p.setSource( "testCall", " \
+void testCall(int a, output int b) \n\
+{ \n\
+  b = a + 1; \n\
+  return; \n\
+}");
+      p.compile();
+      GTLTEST_CHECK_REQUIRED(p.isCompiled());
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Integer8, 1));
+      GTLTEST_CHECK_REQUIRED(Program.isInitialised());
+      GTLCore::Array arr( 100 );
+      Program.apply(arr, arr, &report);
+      GTLTEST_CHECK_EQUAL( report.pixel, 100 );
+      GTLTEST_CHECK_EQUAL( report.row, 0 );
+    }
+};
+
+class TestChannelFlagsProgram : public GTLTest::Case {
+  public:
+    TestChannelFlagsProgram() : GTLTest::Case("ChannelFlagsProgram") {}
+    virtual void runTest()
+    {
+      OpenCTL::Module p;
+      p.setSource( "testCall", " \
+void testCall(float rIn, float gIn, float bIn, output float rOut, output float gOut, output float bOut) \n\
+{ \n\
+  rOut = rIn + 1; \n\
+  gOut = gIn / 2.0; \n\
+  bOut = bIn * 0.5; \n\
+  return; \n\
+}");
+      p.compile();
+      GTLTEST_CHECK_REQUIRED(p.isCompiled());
+      OpenCTL::Program Program( "testCall", &p, GTLCore::PixelDescription( GTLCore::Type::Float32, 3));
+      GTLTEST_CHECK_REQUIRED(Program.isInitialised());
+      GTLCore::Array arr( 6 * sizeof(float));
+      arr.data<float>()[0] = 10;
+      arr.data<float>()[1] = 30;
+      arr.data<float>()[2] = 50;
+      arr.data<float>()[3] = 60;
+      arr.data<float>()[4] = 20;
+      arr.data<float>()[5] = 40;
+      GTLCore::Array arrOut( 6 * sizeof(float));
+      GTLCore::ChannelsFlags flags;
+      flags.disableChannel(1);
+      memset(arrOut.rawData(), 0, arrOut.size());
+      Program.apply(arr, arrOut, 0, flags);
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[0], 11 );
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[1], 0 );
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[2], 25 );
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[3], 61 );
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[4], 0 );
+      GTLTEST_CHECK_NEAR_EQUAL( arrOut.data<float>()[5], 20 );
+    }
+};
+
 class TestProgram : public GTLTest::Suite {
   public:
     TestProgram() : GTLTest::Suite("TestProgram")
@@ -651,5 +732,7 @@ class TestProgram : public GTLTest::Suite {
       addCase(new TestRgb32FloatExposureProgram);
       addCase(new TestMultiInputsProgram);
       addCase(new TestMultiDifferentInputsProgram);
+      addCase(new TestProgressReportProgram);
+      addCase(new TestChannelFlagsProgram);
     }
 };
