@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
+ *  Copyright (c) 2008,2010 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,12 +19,15 @@
 
 #include "AccessorExpression.h"
 
+#include <llvm/ADT/ArrayRef.h>
 #include <llvm/Constants.h>
+#include <llvm/Function.h>
 #include <llvm/Instructions.h>
 
 #include "../LLVMBackend/CodeGenerator_p.h"
 #include "../LLVMBackend/ExpressionResult_p.h"
 #include "../Function.h"
+#include "../Function_p.h"
 #include "../Debug.h"
 #include "../VariableNG_p.h"
 #include "../LLVMBackend/Visitor_p.h"
@@ -65,7 +68,7 @@ llvm::BasicBlock* AccessorExpression::affect( LLVMBackend::GenerationContext& _g
 {
   llvm::Value* ptr_ = pointer( _gc, _egc );
   const LLVMBackend::Visitor* visitor = LLVMBackend::Visitor::getVisitorFor( type() );
-  return visitor->set( _gc, _egc.currentBasicBlock(), ptr_, type(), _value.value(), _value.type(), allocatedInMemory());
+  return visitor->set( _gc, _egc.currentBasicBlock(), ptr_, type(), _value.value(), _value.type());
 }
 
 //------------------- ArraySizeAccessorExpression -------------------//
@@ -123,7 +126,7 @@ llvm::Value* StructAccessorExpression::pointer(LLVMBackend::GenerationContext& _
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(m_index + STRUCT_FIRST_ELEMENT)));
   llvm::Value* ptr = m_parent->pointer( _gc, _egc);
-  llvm::Value* val = llvm::GetElementPtrInst::Create( ptr, indexes.begin(), indexes.end(), "", _egc.currentBasicBlock());
+  llvm::Value* val = llvm::GetElementPtrInst::Create( ptr, indexes, "", _egc.currentBasicBlock());
   GTL_DEBUG( val );
   return val;
 }
@@ -143,6 +146,25 @@ void StructAccessorExpression::markAsReturnExpression()
   m_parent->markAsReturnExpression();
 }
 
+llvm::BasicBlock* StructAccessorExpression::affect( LLVMBackend::GenerationContext& _gc, LLVMBackend::ExpressionGenerationContext& _egc, const LLVMBackend::ExpressionResult& _value )
+{
+  const Type::StructDataMember::Information* info = m_parent->type()->structDataMember(m_index).information();
+  if(info and info->setter())
+  {
+    llvm::Function* llvmFunction = info->setter()->d->data->function( );
+    
+    std::vector<llvm::Value*> convertedParams;
+    convertedParams.push_back(m_parent->pointer( _gc, _egc));
+    convertedParams.push_back(_value.value());
+    
+    llvm::CallInst *CallInst = llvm::CallInst::Create(llvmFunction, convertedParams, "", _egc.currentBasicBlock());
+    CallInst->setTailCall(false);
+    return _egc.currentBasicBlock();
+  } else {
+    return AccessorExpression::affect(_gc, _egc, _value);
+  }
+}
+
 //------------------- ArrayAccessorExpression -------------------//
 
 ArrayAccessorExpression::ArrayAccessorExpression(AccessorExpression * _parent, Expression* _index) : m_parent(_parent), m_index(_index)
@@ -162,6 +184,7 @@ llvm::Value* ArrayAccessorExpression::pointer(LLVMBackend::GenerationContext& _g
   GTL_ASSERT(ptr_);
   const LLVMBackend::Visitor* visitor = LLVMBackend::Visitor::getVisitorFor( m_parent->type() );
   llvm::Value* index = m_index->generateValue(_gc, _egc).value();
+  GTL_DEBUG(*ptr_ << *ptr_->getType());
   llvm::Value* val = visitor->pointerToIndex(_gc, _egc, ptr_, m_parent->type(), index );
   GTL_DEBUG( *val );
   return val;
@@ -195,7 +218,7 @@ llvm::Value* VariableAccessorExpression::pointer(LLVMBackend::GenerationContext&
 {
   GTL_DEBUG("VariableAccessorExpression::pointer");
   llvm::Value* val = m_variable->pointer(_egc.currentBasicBlock());
-  GTL_DEBUG(*val);
+  GTL_DEBUG(*val << *val->getType());
   return val;
 }
 
@@ -209,16 +232,6 @@ const GTLCore::Type* VariableAccessorExpression::type() const
   return m_variable->type();
 }
 
-void VariableAccessorExpression::markAsReturnExpression()
-{
-  m_variable->setAllocatedInMemory( true );
-}
-
-bool VariableAccessorExpression::allocatedInMemory() const
-{
-  return m_variable->allocatedInMemory();
-}
-
 llvm::BasicBlock* VariableAccessorExpression::affect( LLVMBackend::GenerationContext& _gc, LLVMBackend::ExpressionGenerationContext& _egc, const LLVMBackend::ExpressionResult& _value )
 {
   if( _value.functionResult() and (type()->dataType() == Type::ARRAY or type()->dataType() == Type::STRUCTURE ) and not m_variable->constantPointer() )
@@ -229,6 +242,10 @@ llvm::BasicBlock* VariableAccessorExpression::affect( LLVMBackend::GenerationCon
   }
 }
 
+void VariableAccessorExpression::markAsReturnExpression()
+{
+}
+
 //------------------- FunctionMemberAccessorExpression -------------------//
 
 FunctionMemberAccessorExpression::FunctionMemberAccessorExpression( AccessorExpression * _parent, 
@@ -271,12 +288,6 @@ llvm::Value* FunctionMemberAccessorExpression::pointer(LLVMBackend::GenerationCo
   return 0;
 }
 
-bool FunctionMemberAccessorExpression::allocatedInMemory() const
-{
-  GTL_ABORT("No memory is allocated for a function member accessor.");
-  return false;
-}
-
 void FunctionMemberAccessorExpression::markAsReturnExpression()
 {
   // There is no easy way to know if an Array/Structure given as argument of a function
