@@ -32,7 +32,7 @@ namespace GTLCore {
      * This is the base class of binary expressions ( '<', '==', '+', '%'...).
      * @ingroup GTLCore_AST
      */
-    class BinaryExpression : public Expression {
+    class GTLCORE_EXPORT BinaryExpression : public Expression {
       public:
         BinaryExpression( Expression* lhs, Expression* rhs) : m_lhs(lhs), m_rhs(rhs) {}
         ~BinaryExpression();
@@ -281,7 +281,7 @@ namespace GTLCore {
      * expression must be a @ref VariableExpression.
      * @ingroup GTLCore_AST
      */
-    class AssignementBinaryExpression : public BinaryExpression {
+    class GTLCORE_EXPORT AssignementBinaryExpression : public BinaryExpression {
       public:
         AssignementBinaryExpression( AccessorExpression* lhs, Expression* rhs );
         virtual llvm::BasicBlock* generateStatement( LLVMBackend::GenerationContext&, llvm::BasicBlock* ) const;
