@@ -59,9 +59,10 @@ namespace GTLCore {
         virtual void markAsReturnExpression() = 0;
       public:
         /**
+         * @param _declarationType is used for structure whose Value's type is different from their actual type
          * @return an \ref AST::Expression corresponding to the value @p _val given in parameter.
          */
-        static AST::Expression* fromValue( const GTLCore::Value& _val);
+        static AST::Expression* fromValue( const GTLCore::Value& _val, const GTLCore::Type* _declarationType = 0);
     };
 
     /**
@@ -82,8 +83,7 @@ namespace GTLCore {
      */
     class ProxyExpression : public Expression {
       public:
-        ProxyExpression( Expression* expr ) : m_clone( expr)
-        {}
+        ProxyExpression( Expression* expr );
         virtual const GTLCore::Type* type() const { return m_clone->type(); }
         virtual bool isConstant() const { return m_clone->isConstant(); }
         virtual LLVMBackend::ExpressionResult generateValue( LLVMBackend::GenerationContext& _gc, LLVMBackend::ExpressionGenerationContext& ) const;
@@ -106,9 +106,10 @@ namespace GTLCore {
         virtual bool isConstant() const { return true; }
         virtual LLVMBackend::ExpressionResult generateValue( LLVMBackend::GenerationContext& _gc, LLVMBackend::ExpressionGenerationContext& ) const;
         virtual ExpressionResultSP generateValue( GenerationVisitor* _generationVisitor) const;
-        virtual void markAsReturnExpression() { m_expression->markAsReturnExpression(); }
+        virtual void markAsReturnExpression() { m_expression->markAsReturnExpression(); m_isreturn = true; }
       private:
         Expression* m_expression;
+        bool m_isreturn;
     };
     /**
      * @internal
