@@ -90,7 +90,7 @@ void FunctionDeclaration::generate( GTLCore::ModuleData* _module, llvm::Module*
   GTL_DEBUG("Generate function " << m_function->name() );
   m_functionData->setModule( _module );
   // Create the list of parameters as in llvm
-  std::vector<const llvm::Type*> params;
+  std::vector< llvm::Type*> params;
   
   if( m_function->d->isReturnedAsPointer() )
   {
@@ -110,7 +110,7 @@ void FunctionDeclaration::generate( GTLCore::ModuleData* _module, llvm::Module*
   }
     
   // Generate the full function
-  const llvm::Type* returnType = m_function->d->isReturnedAsPointer() ? llvm::Type::getVoidTy(*_llvmContext) : m_function->returnType()->d->asArgumentType(*_llvmContext);
+  llvm::Type* returnType = m_function->d->isReturnedAsPointer() ? llvm::Type::getVoidTy(*_llvmContext) : m_function->returnType()->d->asArgumentType(*_llvmContext);
   llvm::FunctionType* definitionType = llvm::FunctionType::get( returnType, params, false );
   GTLCore::String fullFunctionName = GTLCore::Function::Data::symbolName( m_function->name(), m_function->returnType(), m_function->parameters());
   llvm::Function* fullFunction = _codeGenerator->createFunction( _llvmModule, definitionType, fullFunctionName );
