@@ -49,7 +49,7 @@ llvm::BasicBlock* PointerGarbageCollectionStatement::generateStatement( LLVMBack
     llvm::Value* test = LLVMBackend::CodeGenerator::createStrictInferiorExpression( _currentBlock, countValue, Type::Integer32, LLVMBackend::CodeGenerator::integerToConstant( _generationContext.llvmContext(), INT32_C(1) ), Type::Integer32 );
     llvm::BasicBlock* first = createBlock( _generationContext );
     llvm::BasicBlock* after = createBlock( _generationContext );
-    llvm::BasicBlock* last = LLVMBackend::Visitor::getVisitorFor( m_type )->cleanUp( _generationContext, first, m_pointer, m_type, 0, true, false, true );
+    llvm::BasicBlock* last = LLVMBackend::Visitor::getVisitorFor( m_type )->cleanUp( _generationContext, first, m_pointer, m_type, 0, false, true );
     LLVMBackend::CodeGenerator::createIfStatement( _currentBlock, test, Type::Boolean, first, last, after);
     return after;
   } else {
