@@ -21,6 +21,7 @@
 
 #include <llvm/Constant.h>
 #include <llvm/GlobalVariable.h>
+#include <llvm/Type.h>
 
 #include "FunctionDeclaration.h"
 
@@ -36,17 +37,19 @@
 #include "GTLCore/LLVMBackend/Visitor_p.h"
 
 #include "Expression.h"
+#include <llvm/Module.h>
+#include <llvm/DerivedTypes.h>
 
 using namespace GTLCore::AST;
 
-GlobalConstantDeclaration::GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, Expression* _initialiser, bool _dependant) :
-    m_name( _name), m_initialiser(_initialiser), m_variable( new GTLCore::VariableNG( _type, true, _dependant ) ), m_type(_type), m_constant(not _dependant)
+GlobalConstantDeclaration::GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, Expression* _initialiser, bool _dependant, bool _external) :
+    m_name( _name), m_initialiser(_initialiser), m_variable( new GTLCore::VariableNG( _type, true, _dependant ) ), m_type(_type), m_constant(not _dependant), m_external(_external)
 {
   GTL_ASSERT( _initialiser );
 }
 
-GlobalConstantDeclaration::GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, const std::list< int >& sizes, bool _dependant) :
-    m_name( _name), m_initialiser(0), m_variable( new GTLCore::VariableNG( _type, true, _dependant ) ), m_type(_type), m_sizes(sizes), m_constant(not _dependant)
+GlobalConstantDeclaration::GlobalConstantDeclaration( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, const std::list< int >& sizes, bool _dependant, bool _external) :
+    m_name( _name), m_initialiser(0), m_variable( new GTLCore::VariableNG( _type, true, _dependant ) ), m_type(_type), m_sizes(sizes), m_constant(not _dependant), m_external(_external)
 {
 }
 
@@ -60,21 +63,42 @@ GlobalConstantDeclaration::~GlobalConstantDeclaration()
 void GlobalConstantDeclaration::generate( GTLCore::ModuleData* _module, llvm::Module* _llvmModule, LLVMBackend::CodeGenerator* _codeGenerator, llvm::LLVMContext* _llvmContext)
 {
   LLVMBackend::GenerationContext gc( _codeGenerator, _llvmContext, 0, 0, _module, _llvmModule);
+  llvm::Value* pointer = 0;
   
-  llvm::Constant* value = 0;
-  if( m_initialiser )
+  if(m_external)
   {
-    GTL_DEBUG(*m_initialiser->type());
-    LLVMBackend::ExpressionGenerationContext egc(0);
-    value = _codeGenerator->convertConstantTo( m_initialiser->generateValue( gc, egc ).constant(), m_initialiser->type() , m_type );
-    GTL_ASSERT( value );
+    pointer = _llvmModule->getOrInsertGlobal((const std::string&)nameToSymbol(), m_type->d->type(*_llvmContext));
   } else {
-    value = LLVMBackend::Visitor::getVisitorFor( m_type )->createStaticVariable( _llvmModule, m_type, m_sizes );
+    llvm::Constant* value = 0;
+    if( m_initialiser )
+    {
+      GTL_DEBUG(*m_initialiser->type());
+      LLVMBackend::ExpressionGenerationContext egc(0);
+      value = _codeGenerator->convertConstantTo( m_initialiser->generateValue( gc, egc ).constant(), m_initialiser->type() , m_type );
+      GTL_ASSERT( value );
+    } else {
+      value = LLVMBackend::Visitor::getVisitorFor( m_type )->createStaticVariable( _llvmModule, m_type, m_sizes );
+    }
+    pointer = new llvm::GlobalVariable( *_llvmModule, value ? value->getType() : m_type->d->type(*_llvmContext) , m_constant, llvm::GlobalValue::ExternalLinkage, value, (const std::string&)nameToSymbol() );
   }
-  llvm::Value* pointer = new llvm::GlobalVariable( *_llvmModule, value ? value->getType() : m_type->d->type(*_llvmContext) , m_constant, llvm::GlobalValue::InternalLinkage, value, "" );
+  GTL_ASSERT(pointer);
   m_variable->initialise( gc, 0, pointer);
 }
 
+GTLCore::String GlobalConstantDeclaration::nameToSymbol()
+{
+  return nameToSymbol(m_name);
+}
+
+GTLCore::String GlobalConstantDeclaration::nameToSymbol(const GTLCore::ScopedName& name)
+{
+  if(name.nameSpace().isEmpty())
+  {
+    return name.name();
+  } else {
+    return name.nameSpace() + "_" + name.name();
+  }
+}
 
 Tree::Tree()
 {
