@@ -24,6 +24,9 @@
 #include "Region.h"
 
 namespace GTLCore {
+
+class AbstractColorConverter;
+
   class Buffer;
   class PixelDescription;
   class RegionI;
@@ -92,7 +95,7 @@ namespace GTLCore {
           virtual Buffer* current() = 0;
       };
     public:
-      AbstractImage( const GTLCore::PixelDescription& _pixelDescription );
+      AbstractImage( const GTLCore::PixelDescription& _pixelDescription, const AbstractColorConverter* _colorConverter = 0 );
       virtual ~AbstractImage();
     public:
       /**
@@ -142,6 +145,10 @@ namespace GTLCore {
        * Create an iterator on the buffer of the image
        */
       virtual Iterator* createIterator() = 0;
+      /**
+       * @return the color converter associated with this image
+       */
+      const GTLCore::AbstractColorConverter* colorConverter() const;
     protected:
       int pixelSize() const;
     private:
