@@ -40,7 +40,7 @@ namespace GTLCore {
        * 
        * It is expected that (_width * _height * _pixelDescription.bitsSize() / 8) == _buffer->size()
        */
-      BufferImage( int _width, int _height, GTLCore::Buffer* _buffer, const GTLCore::PixelDescription& _pixelDescription );
+      BufferImage( int _width, int _height, GTLCore::Buffer* _buffer, const GTLCore::PixelDescription& _pixelDescription, const AbstractColorConverter* _colorConverter = 0 );
       ~BufferImage();
     public:
       virtual char* rawData( int _x, int _y );
