@@ -23,6 +23,7 @@
 #include <GTLCore/Export.h>
 
 namespace GTLCore {
+  struct RgbaF;
   class GTLCORE_EXPORT Color {
     public:
       Color();
@@ -39,6 +40,7 @@ namespace GTLCore {
       void setGreen(float r);
       void setBlue(float r);
       void setAlpha(float r);
+      const RgbaF& rgbaf() const;
     private:
       void deref();
       struct Private;
