@@ -21,9 +21,11 @@
 
 namespace GTLCore {
   struct CompilationMessages::Private {
+    friend class CompilationMessages;
+    GTLCORE_EXPORT void appendMessage(const CompilationMessage& _message);
+  private:
     std::list<CompilationMessage> errors;
     std::list<CompilationMessage> warnings;
     std::list<CompilationMessage> messages;
-    GTLCORE_EXPORT void appendMessage(const CompilationMessage& _message);
   };
 }
