@@ -29,6 +29,9 @@ namespace llvm {
 }
 
 namespace GTLCore {
+
+class OperatorOverloadCenter;
+
   class ConvertCenter;
   class CompilationMessage;
   class CompilationMessages;
@@ -37,6 +40,7 @@ namespace GTLCore {
   class TypesManager;
   class Type;
   class ModuleData;
+  class Value;
   namespace AST {
     class Expression;
   }
@@ -55,9 +59,11 @@ namespace GTLCore {
        * Append the error and delete the message.
        */
       void appendError( GTLCore::CompilationMessage* );
+      void appendErrors( const std::list<GTLCore::CompilationMessage>& _msgs);
       const CompilationMessages& errorMessages() const;
       const std::list<GTLCore::Function*>* function( const GTLCore::ScopedName&  );
       bool declareFunction( const GTLCore::ScopedName&, GTLCore::Function*);
+      bool declareConstant( const GTLCore::ScopedName& _name, const GTLCore::Type* _type, const GTLCore::Value& _value);
       /**
        * 
        * @return the type manager used for compilation
@@ -67,10 +73,13 @@ namespace GTLCore {
        * @return the \ref ConvertCenter used for compilation
        */
       ConvertCenter* convertCenter();
+      /**
+       * @return the \ref OperatorOverloadCenter used for compilation
+       */
+      OperatorOverloadCenter* operatorOverloadCenter();
     public:
       virtual GTLCore::AST::Expression* standardConstant( const GTLCore::String& _name ) = 0;
     protected:
-      void appendErrors( const std::list<GTLCore::CompilationMessage>& _msgs);
       void setModuleName( const GTLCore::String& moduleName);
       const GTLCore::String& moduleName() const;
        /// List of functions which are not visible in the generated module (like functions coming from an imported module, or standard library functions, and that should be removed at the end of compilation
