@@ -99,6 +99,11 @@ namespace llvm {
 #  define FUNC_INFO ""
 #endif
 
+/**
+ * Use this macro to display in the output stream the name of a variable followed by its value.
+ */
+#define ppVar( var ) #var << "=" << var << " "
+
 #define GTL_WARNING(msg) \
   GTLCore::Debug::warning(COUMPONENT_NAME, __FILE__, __LINE__, FUNC_INFO ) << msg << std::endl;
 
@@ -123,6 +128,11 @@ namespace llvm {
   { \
     GTL_ABORT( "Assertion failed: " << #assrt ); \
   }
+#define GTL_ASSERT_X(assrt, msg) \
+  if( not (assrt ) ) \
+  { \
+    GTL_ABORT( "Assertion failed: " << #assrt << " (" << msg << ")" ); \
+  }
 #define GTL_CHECK_PTR(ptr) \
   if( not (assrt ) ) \
   { \
@@ -133,6 +143,11 @@ namespace llvm {
   { \
     GTL_ABORT( #val1 << " != " << #val2 ); \
   }
+#define GTL_CHECK_LLVM_EQUAL(val1, val2) \
+  if( val1 != val2 ) \
+  { \
+    GTL_ABORT( *(val1) << " != " << *(val2) ); \
+  }
 
 
 #include <vector>
@@ -146,8 +161,10 @@ GTLCORE_DEBUG_EXPORT void compareFunctionParameters( llvm::Value* func, const st
 
 #define GTL_DEBUG(msg)
 #define GTL_ASSERT(assrt)
+#define GTL_ASSERT_X(assrt, msg)
 #define GTL_CHECK_PTR(ptr) (void)ptr;
 #define GTL_CHECK_EQUAL(val1, val2) (void)val1; (void)val2;
+#define GTL_CHECK_LLVM_EQUAL(val1, val2) (void)val1; (void)val2;
 #define GTL_COMPARE_FUNCTION_PARAMETERS( _FUNC_, _PARAMS_ ) (void)_FUNC_; (void)_PARAMS_; \
 
 #endif
