@@ -77,7 +77,7 @@ Function* Function::Private::createExternalFunction(ModuleData* _module, llvm::M
   const llvm::Function* func = _functionToCopy->d->data->function();
   llvm::FunctionType *FTy =
     llvm::cast<llvm::FunctionType>(llvm::cast<llvm::PointerType>(func->getType())->getElementType());
-  llvm::Function* function = dynamic_cast<llvm::Function*>( _llvmModule->getOrInsertFunction( (const std::string&)_symbolName, FTy) );
+  llvm::Function* function = llvm::dyn_cast<llvm::Function>( _llvmModule->getOrInsertFunction( (const std::string&)_symbolName, FTy) );
   GTLCore::Function::Data* data = new GTLCore::Function::Data( _functionToCopy->parameters(), _functionToCopy->d->data->minimumParameters() );
   data->setFunction( function );
   data->setModule( _module );
@@ -137,7 +137,7 @@ GTLCore::Function* Function::Private::createExternalFunction(ModuleData* _module
     }
     llvmArguments.push_back( type );
   }
-  llvm::Function* function = dynamic_cast<llvm::Function*>( _llvmModule->getOrInsertFunction( (const std::string&)_symbolName, llvm::FunctionType::get( retType->d->asArgumentType(_context), llvmArguments, false ) ) );
+  llvm::Function* function = llvm::dyn_cast<llvm::Function>( _llvmModule->getOrInsertFunction( (const std::string&)_symbolName, llvm::FunctionType::get( retType->d->asArgumentType(_context), llvmArguments, false ) ) );
   GTLCore::Function::Data* data = new GTLCore::Function::Data(arguments, minimumParameters == -1 ? arguments.size() : minimumParameters );
   data->setFunction( function );
   data->setModule( _module );
