@@ -48,8 +48,12 @@ namespace GTLCore {
     FunctionCaller* functionsCaller;
     GTLCORE_EXPORT static Function* createExternalFunction(GTLCore::ModuleData* _module, llvm::Module* _llvmModule, llvm::LLVMContext& _context, const GTLCore::Function* _functionToCopy );
     GTLCORE_EXPORT static Function* createExternalFunction(GTLCore::ModuleData* _module, llvm::Module* _llvmModule, llvm::LLVMContext& _context, const GTLCore::String& _name, const GTLCore::String& _symbolName, const GTLCore::Type* retType, const std::vector< GTLCore::Parameter >& arguments);
-    GTLCORE_EXPORT static Function* createExternalFunction(GTLCore::ModuleData* _module, llvm::Module* _llvmModule, llvm::LLVMContext& _context, const GTLCore::String& _name, const GTLCore::String& _symbolName, const GTLCore::Type* retType, int _count, ...);
-    GTLCORE_EXPORT static Function* createInternalFunction(ModuleData* _module, llvm::LLVMContext& _context, const String& _name, llvm::Function* _function, const Type* retType, int _count, ...);
+    enum ExternalFunctionParameters {
+      EFP_ONLY_TYPE,
+      EFP_TYPE_AND_DEFAULT
+    };
+    GTLCORE_EXPORT static Function* createExternalFunction(GTLCore::ModuleData* _module, llvm::Module* _llvmModule, llvm::LLVMContext& _context, const GTLCore::String& _name, const GTLCore::String& _symbolName, const GTLCore::Type* retType, ExternalFunctionParameters efpParameter, int _count, ...);
+    GTLCORE_EXPORT static Function* createInternalFunction(ModuleData* _module, llvm::LLVMContext& _context, const String& _name, llvm::Function* _function, const Type* retType, ExternalFunctionParameters efpParameter, int _count, ...);
     bool isReturnedAsPointer() const;
   };
   /**
