@@ -27,7 +27,7 @@ using namespace GTLCore;
 struct Image::Private {
 };
 
-Image::Image(int _width, int _height, const PixelDescription& _pixelDescription) : BufferImage(_width, _height, new Array(_height * _width * _pixelDescription.bitsSize() / 8), _pixelDescription ), d(new Private)
+Image::Image(int _width, int _height, const PixelDescription& _pixelDescription, const AbstractColorConverter* _colorConverter) : BufferImage(_width, _height, new Array(_height * _width * (_pixelDescription.bitsSize() / 8)), _pixelDescription, _colorConverter ), d(new Private)
 {
 }
 
