@@ -35,7 +35,7 @@ namespace GTLCore {
   class GTLCORE_EXPORT Image : public BufferImage {
       GTL_NO_COPY(Image);
     public:
-      Image(int _width, int _height, const PixelDescription& _pixelDescription);
+      Image(int _width, int _height, const GTLCore::PixelDescription& _pixelDescription, const GTLCore::AbstractColorConverter* _colorConverter = 0 );
       ~Image();
     private:
       struct Private;
