@@ -209,16 +209,16 @@ Value CodeGenerator::constantToValue(llvm::Constant* constant, const Type* _type
   if( constant->getType() == llvm::Type::getInt32Ty(constant->getContext() ) )
   {
     GTL_ASSERT(_type == Type::Integer32 or _type == Type::UnsignedInteger32 );
-    return gtl_int32(dynamic_cast<llvm::ConstantInt* >( constant )->getValue().getLimitedValue());
+    return gtl_int32(llvm::dyn_cast<llvm::ConstantInt>( constant )->getValue().getLimitedValue());
   } else if ( constant->getType() == llvm::Type::getFloatTy(constant->getContext()) )
   {
     GTL_ASSERT(_type == Type::Float32 or _type == Type::Float16 );
-    return dynamic_cast<llvm::ConstantFP* >( constant )->getValueAPF().convertToFloat();
+    return llvm::dyn_cast<llvm::ConstantFP>( constant )->getValueAPF().convertToFloat();
   } else if ( constant->getType() == llvm::Type::getInt1Ty(constant->getContext()) ) {
     GTL_ASSERT(_type == Type::Boolean );
-	return dynamic_cast<llvm::ConstantInt* >( constant )->getValue().getLimitedValue() != 0;
+	return llvm::dyn_cast<llvm::ConstantInt>( constant )->getValue().getLimitedValue() != 0;
   } else if( constant->getType()->getTypeID() == llvm::Type::StructTyID ) {
-    llvm::ConstantStruct* cs = dynamic_cast<llvm::ConstantStruct* >( constant );
+    llvm::ConstantStruct* cs = llvm::dyn_cast<llvm::ConstantStruct>( constant );
     switch(_type->dataType())
     {
       case Type::STRUCTURE:
@@ -235,12 +235,12 @@ Value CodeGenerator::constantToValue(llvm::Constant* constant, const Type* _type
       {
         GTL_ASSERT( cs->getNumOperands() == 2 + STRUCT_FIRST_ELEMENT );
         GTL_ASSERT( cs->getOperand(1)->getType() == llvm::Type::getInt32Ty(constant->getContext()) );
-		std::size_t sizeArray = std::size_t(dynamic_cast<llvm::ConstantInt* >( cs->getOperand(1))->getValue().getLimitedValue());
-        llvm::ConstantExpr* expr = dynamic_cast<llvm::ConstantExpr*>(cs->getOperand(2));
+		std::size_t sizeArray = std::size_t(llvm::dyn_cast<llvm::ConstantInt>( cs->getOperand(1))->getValue().getLimitedValue());
+        llvm::ConstantExpr* expr = llvm::dyn_cast<llvm::ConstantExpr>(cs->getOperand(2));
         GTL_ASSERT(expr);
-        llvm::GlobalVariable* arrayGV = dynamic_cast<llvm::GlobalVariable*>(expr->getOperand(0));
+        llvm::GlobalVariable* arrayGV = llvm::dyn_cast<llvm::GlobalVariable>(expr->getOperand(0));
         GTL_ASSERT(arrayGV);
-        llvm::ConstantArray* array = dynamic_cast<llvm::ConstantArray*>(arrayGV->getInitializer());
+        llvm::ConstantArray* array = llvm::dyn_cast<llvm::ConstantArray>(arrayGV->getInitializer());
         GTL_ASSERT(array);
         GTL_ASSERT(array->getNumOperands() == sizeArray);
         std::vector< Value > values;
@@ -254,7 +254,7 @@ Value CodeGenerator::constantToValue(llvm::Constant* constant, const Type* _type
         GTL_ABORT("Unsupported type");
     }
   } else if( constant->getType()->getTypeID() == llvm::Type::PointerTyID) {
-    return constantToValue( dynamic_cast<llvm::GlobalVariable*>(constant)->getInitializer() , _type);
+    return constantToValue( llvm::dyn_cast<llvm::GlobalVariable>(constant)->getInitializer() , _type);
   } else {
     GTL_ABORT("Unimplemented");
   }
@@ -316,7 +316,7 @@ llvm::Value* CodeGenerator::convertPointerTo(llvm::BasicBlock* _currentBlock, ll
 llvm::Value* CodeGenerator::convertValueTo(llvm::BasicBlock* _currentBlock, llvm::Value* _value, const Type* _valueType, const Type* _targetType)
 {
   GTL_DEBUG("Convert value " << *_value << " from " << *_valueType << " to " << *_targetType);
-  llvm::Constant* _constant = dynamic_cast<llvm::Constant*>(_value);
+  llvm::Constant* _constant = llvm::dyn_cast<llvm::Constant>(_value);
   if(_constant)
   {
     return convertConstantTo( _constant, _valueType, _targetType);
@@ -386,7 +386,7 @@ llvm::Value* CodeGenerator::convertToHalf( LLVMBackend::GenerationContext& _gene
 {
   std::vector< llvm::Type*> llvmArguments;
   llvmArguments.push_back( llvm::Type::getFloatTy(_generationContext.llvmContext()) );
-  llvm::Function* func = dynamic_cast<llvm::Function*>( _generationContext.llvmModule()->getOrInsertFunction( "_Z10float2halff",
+  llvm::Function* func = llvm::dyn_cast<llvm::Function>( _generationContext.llvmModule()->getOrInsertFunction( "_Z10float2halff",
       llvm::FunctionType::get( llvm::Type::getInt16Ty(_generationContext.llvmContext()) , llvmArguments, false ) ) );
   std::vector<llvm::Value*> convertedParams;
   convertedParams.push_back( convertValueTo( currentBlock, value, _valueType, Type::Float32 ) );
@@ -397,7 +397,7 @@ llvm::Value* CodeGenerator::convertFromHalf( LLVMBackend::GenerationContext& _ge
 {
   std::vector<llvm::Type*> llvmArguments;
   llvmArguments.push_back( llvm::Type::getInt16Ty(_generationContext.llvmContext()) );
-  llvm::Function* func = dynamic_cast<llvm::Function*>( _generationContext.llvmModule()->getOrInsertFunction( "_Z10half2floatt",
+  llvm::Function* func = llvm::dyn_cast<llvm::Function>( _generationContext.llvmModule()->getOrInsertFunction( "_Z10half2floatt",
       llvm::FunctionType::get( llvm::Type::getFloatTy(_generationContext.llvmContext()) , llvmArguments, false ) ) );
   std::vector<llvm::Value*> convertedParams;
   convertedParams.push_back( convertValueTo( currentBlock, value, Type::Float16, Type::Integer16 ) );
@@ -461,14 +461,14 @@ llvm::Constant* CodeGenerator::convertConstantArrayToVector(llvm::Constant* cons
 {
   GTL_DEBUG(*constant);
   GTL_DEBUG(*constant->getType());
-  llvm::ConstantStruct* arrayConstant = dynamic_cast<llvm::ConstantStruct*>(constant->getOperand(0));
+  llvm::ConstantStruct* arrayConstant = llvm::dyn_cast<llvm::ConstantStruct>(constant->getOperand(0));
   GTL_ASSERT(arrayConstant);
   GTL_ASSERT(constantType->dataType() == Type::ARRAY );
   GTL_ASSERT(type->dataType() == Type::VECTOR );
   GTL_ASSERT(arrayConstant->getNumOperands() == 3 );
   llvm::Constant* values = llvm::cast<llvm::Constant>(llvm::cast<llvm::Constant>(arrayConstant->getOperand(2)->getOperand(0))->getOperand(0));
   GTL_DEBUG(*values);
-  GTL_ASSERT(dynamic_cast<llvm::ConstantArray*>(values) );
+  GTL_ASSERT(llvm::dyn_cast<llvm::ConstantArray>(values) );
   std::vector<llvm::Constant*> constants;
   for(unsigned int i = 0; i < values->getNumOperands(); ++i )
   {
@@ -1238,3 +1238,8 @@ llvm::BasicBlock* CodeGenerator::createClampExpression( LLVMBackend::GenerationC
 
   return lastBlock;
 }
+
+llvm::Constant* CodeGenerator::stringToConstant(llvm::LLVMContext& _llvmContext, const String& string)
+{
+ return llvm::ConstantDataArray::getString(_llvmContext, (const std::string&)string, true );
+}
