@@ -70,6 +70,10 @@ namespace LLVMBackend {
        */
       CodeGenerator(GTLCore::ModuleData* module);
       ~CodeGenerator();
+      /**
+       * Create a null terminated string
+       */
+      static llvm::Constant* stringToConstant(llvm::LLVMContext& _llvmContext, const GTLCore::String& string);
       /**
        * @return an integer constant
        */
