@@ -115,7 +115,7 @@ ExpressionResult PrimitiveVisitor::get( LLVMBackend::GenerationContext& _generat
   return ExpressionResult( new llvm::LoadInst( _pointer, "PrimitiveVisitor::get", _currentBlock), _pointerType);
 }
 
-llvm::BasicBlock* PrimitiveVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType, bool _allocatedInMemory ) const
+llvm::BasicBlock* PrimitiveVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType ) const
 {
   GTL_ASSERT( _pointerType->dataType() != Type::STRUCTURE and _pointerType->dataType() != Type::ARRAY and _pointerType->dataType() != Type::VECTOR );
   GTL_DEBUG( *_pointer );
@@ -125,13 +125,13 @@ llvm::BasicBlock* PrimitiveVisitor::set( LLVMBackend::GenerationContext& _genera
   return _currentBlock;
 }
 
-llvm::BasicBlock* PrimitiveVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes, bool _allocatedInMemory) const
+llvm::BasicBlock* PrimitiveVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes) const
 {
   // Don't do nothing
   return _currentBlock;
 }
 
-llvm::BasicBlock* PrimitiveVisitor::cleanUp( LLVMBackend::GenerationContext& , llvm::BasicBlock* _currentBlock, llvm::Value* , const Type* , llvm::Value* , bool, bool /*_ignoreCount*/, bool /*_deletePointer*/ ) const
+llvm::BasicBlock* PrimitiveVisitor::cleanUp( LLVMBackend::GenerationContext& , llvm::BasicBlock* _currentBlock, llvm::Value* , const Type* , llvm::Value* , bool /*_ignoreCount*/, bool /*_deletePointer*/ ) const
 {
   return _currentBlock;
 }
@@ -171,7 +171,7 @@ ExpressionResult ArrayVisitor::get( LLVMBackend::GenerationContext& _generationC
   return ExpressionResult(_pointer, _pointerType);
 }
 
-llvm::BasicBlock* ArrayVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType, bool _allocatedInMemory) const
+llvm::BasicBlock* ArrayVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType) const
 {
     // Check if size are identical or update the size of this array
     {
@@ -181,9 +181,9 @@ llvm::BasicBlock* ArrayVisitor::set( LLVMBackend::GenerationContext& _generation
       std::list<llvm::Value*> sizes;
       sizes.push_back( getSize( _generationContext, ifContent, _value ) );
       
-      llvm::BasicBlock* endIfContent = cleanUp(_generationContext, ifContent, _pointer, _pointerType, 0, _allocatedInMemory, true, false );
+      llvm::BasicBlock* endIfContent = cleanUp(_generationContext, ifContent, _pointer, _pointerType, 0, true, false );
       
-      endIfContent = initialise( _generationContext, endIfContent, _pointer, _pointerType, sizes, _allocatedInMemory );
+      endIfContent = initialise( _generationContext, endIfContent, _pointer, _pointerType, sizes );
       
       llvm::BasicBlock* afterIf = llvm::BasicBlock::Create( _generationContext.llvmContext() );
       _generationContext.llvmFunction()->getBasicBlockList().push_back( afterIf);
@@ -209,7 +209,7 @@ llvm::BasicBlock* ArrayVisitor::set( LLVMBackend::GenerationContext& _generation
           visitor->get( _generationContext, bodyBlock, 
                   _generationContext.codeGenerator()->accessArrayValueNoClamp(
                                     bodyBlock, _value, index->get( _generationContext, bodyBlock ) ), _pointerType->embeddedType() ).value(),
-          _valueType->embeddedType(), _allocatedInMemory );
+          _valueType->embeddedType());
     
     // Create the for statement
     llvm::BasicBlock* returnBlock = CodeGenerator::createIterationForStatement(
@@ -224,7 +224,7 @@ llvm::BasicBlock* ArrayVisitor::set( LLVMBackend::GenerationContext& _generation
     return returnBlock;
 }
 
-llvm::BasicBlock* ArrayVisitor::setSize(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _size, bool _allocatedInMemory) const
+llvm::BasicBlock* ArrayVisitor::setSize(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _size) const
 {
   GTL_ASSERT( _pointerType->dataType() == Type::ARRAY );
   GTL_DEBUG( *_size );
@@ -233,22 +233,16 @@ llvm::BasicBlock* ArrayVisitor::setSize(LLVMBackend::GenerationContext& _generat
   indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), ArrayWrap::POS_SIZE)); // Access the size of the array
   { // Init the size
     GTL_DEBUG( *_pointer );
-    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "ArrayVisitor::setSize", _currentBlock);
+    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes, "ArrayVisitor::setSize", _currentBlock);
     new llvm::StoreInst(_generationContext.codeGenerator()->convertValueTo( _currentBlock, _size, Type::Integer32, Type::Integer32 ), ptr, "", _currentBlock);
   }
   // Allocate the Array
   indexes[1] = llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), ArrayWrap::POS_DATA);
   {
-    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "ArrayVisitor::setSize", _currentBlock);
+    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes, "ArrayVisitor::setSize", _currentBlock);
     llvm::Value* array = 0;
-    if( _allocatedInMemory )
-    {
-      array = CodeGenerator::allocateMemory( _generationContext,
-                    _pointerType->embeddedType()->d->type(_generationContext.llvmContext()), _size, _currentBlock);
-    } else {
-      array = new llvm::AllocaInst(
-                    _pointerType->embeddedType()->d->type(_generationContext.llvmContext()), _size, "ArrayVisitor::setSize", _currentBlock);
-    }
+    array = CodeGenerator::allocateMemory( _generationContext,
+                  _pointerType->embeddedType()->d->type(_generationContext.llvmContext()), _size, _currentBlock);
     new llvm::StoreInst( array, ptr, "ArrayVisitor::setSize", _currentBlock);
   }
   return _currentBlock;
@@ -259,7 +253,7 @@ llvm::Value* ArrayVisitor::getSize(LLVMBackend::GenerationContext& _generationCo
   return CodeGenerator::accessArraySize(currentBlock, _pointer);
 }
 
-llvm::BasicBlock* ArrayVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes, bool _allocatedInMemory) const
+llvm::BasicBlock* ArrayVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes) const
 {
   GTL_ASSERT( _pointerType->dataType() == Type::ARRAY );
   GTL_DEBUG( _sizes.empty() );
@@ -267,7 +261,7 @@ llvm::BasicBlock* ArrayVisitor::initialise(LLVMBackend::GenerationContext& _gene
   if( not _sizes.empty())
   {
     llvm::Value* currentSize = _sizes.front();
-    _currentBlock = setSize( _generationContext, _currentBlock, _pointer, _pointerType, currentSize, _allocatedInMemory );
+    _currentBlock = setSize( _generationContext, _currentBlock, _pointer, _pointerType, currentSize );
     std::list< llvm::Value*> sizeAfter = _sizes;
     sizeAfter.pop_front();
     //   int i = 0;
@@ -285,7 +279,7 @@ llvm::BasicBlock* ArrayVisitor::initialise(LLVMBackend::GenerationContext& _gene
             _generationContext.codeGenerator()->accessArrayValueNoClamp(
                       bodyBlock, _pointer, index->get( _generationContext, bodyBlock ) ),
             _pointerType->embeddedType(),
-            sizeAfter, _allocatedInMemory );
+            sizeAfter );
     
     // Create the for statement
     llvm::BasicBlock* returnBB = CodeGenerator::createIterationForStatement(
@@ -303,13 +297,13 @@ llvm::BasicBlock* ArrayVisitor::initialise(LLVMBackend::GenerationContext& _gene
     indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), 0)); // Access the structure of the array
     indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), ArrayWrap::POS_SIZE)); // Access the size of the array
     // Init the size
-    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "ArrayVisitor::initialise", _currentBlock);
+    llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pointer, indexes, "ArrayVisitor::initialise", _currentBlock);
     new llvm::StoreInst( CodeGenerator::integerToConstant( _generationContext.llvmContext(), INT32_C(0) ), ptr, "ArrayVisitor::initialise", _currentBlock);
   }
   return _currentBlock;
 }
 
-llvm::BasicBlock* ArrayVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool _allocatedInMemory, bool _ignoreCount, bool _deletePointer ) const
+llvm::BasicBlock* ArrayVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool _ignoreCount, bool _deletePointer ) const
 {
   // TODO use _donttouch in the array as well
     //   int i = 0;
@@ -346,7 +340,7 @@ llvm::BasicBlock* ArrayVisitor::cleanUp( LLVMBackend::GenerationContext& _genera
           _generationContext,
           bodyBlock, 
           _generationContext.codeGenerator()->accessArrayValueNoClamp( bodyBlock, _pointer, index->get( _generationContext, bodyBlock  ) ),
-          _pointerType->embeddedType(), _donttouch, _allocatedInMemory, _ignoreCount, false );
+          _pointerType->embeddedType(), _donttouch, _ignoreCount, false );
     // Create the for statement
     llvm::BasicBlock*  afterBlock = CodeGenerator::createIterationForStatement(
                     _generationContext,
@@ -356,18 +350,15 @@ llvm::BasicBlock* ArrayVisitor::cleanUp( LLVMBackend::GenerationContext& _genera
                     Type::Integer32,
                     bodyBlock,
                     endBodyBlock );
-    if( _allocatedInMemory )
+    std::vector<llvm::Value*> indexes;
+    indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), 0)); // Access the structure of the array
+    indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), ArrayWrap::POS_DATA )); // Access the data of the array
+    // Free the array
+    llvm::Value* ptrToData = llvm::GetElementPtrInst::Create( _pointer, indexes, "ArrayVisitor::cleanUp", afterBlock);
+    CodeGenerator::freeMemory(_generationContext, new llvm::LoadInst( ptrToData, "ArrayVisitor::cleanUp", afterBlock ), afterBlock );
+    if( _deletePointer )
     {
-      std::vector<llvm::Value*> indexes;
-      indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), 0)); // Access the structure of the array
-      indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), ArrayWrap::POS_DATA )); // Access the data of the array
-      // Free the array
-      llvm::Value* ptrToData = llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "ArrayVisitor::cleanUp", afterBlock);
-      CodeGenerator::freeMemory(_generationContext, new llvm::LoadInst( ptrToData, "ArrayVisitor::cleanUp", afterBlock ), afterBlock );
-      if( _deletePointer )
-      {
-        CodeGenerator::freeMemory( _generationContext, _pointer, afterBlock );
-      }
+      CodeGenerator::freeMemory( _generationContext, _pointer, afterBlock );
     }
     
     llvm::BasicBlock* afterIfBlock = llvm::BasicBlock::Create(_generationContext.llvmContext(), "afterIfBlock");
@@ -442,10 +433,10 @@ llvm::Constant* ArrayVisitor::createStaticVariable( llvm::Module* _module, const
   std::vector<llvm::Constant*> indices;
   indices.push_back( CodeGenerator::integerToConstant( _module->getContext(), INT32_C(0) ) );
   indices.push_back( CodeGenerator::integerToConstant( _module->getContext(), INT32_C(0) ) );
-  initialisers.push_back( llvm::ConstantExpr::getGetElementPtr(arrayData, &indices[0], indices.size() ) );
+  initialisers.push_back( llvm::ConstantExpr::getGetElementPtr(arrayData, indices, indices.size() ) );
   
   GTL_DEBUG(* initialisers[2] << " " <<  *type->d->type(_module->getContext()));
-  return llvm::ConstantStruct::get( dynamic_cast<const llvm::StructType*>(type->d->type(_module->getContext())), initialisers );
+  return llvm::ConstantStruct::get( llvm::cast<llvm::StructType>(type->d->type(_module->getContext())), initialisers );
 }
 
 //--------- VectorVisitor ---------///
@@ -474,7 +465,7 @@ ExpressionResult VectorVisitor::get( LLVMBackend::GenerationContext& _generation
   return ExpressionResult(new llvm::LoadInst( _pointer, "VectorVisitor::get", _currentBlock), _pointerType );
 }
 
-llvm::BasicBlock* VectorVisitor::set(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType, bool _allocatedInMemory) const
+llvm::BasicBlock* VectorVisitor::set(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType) const
 {
   GTL_ASSERT( _pointerType->dataType() == Type::VECTOR );
   GTL_DEBUG( "value = " << *_value << " type = " << *_valueType );
@@ -484,13 +475,13 @@ llvm::BasicBlock* VectorVisitor::set(LLVMBackend::GenerationContext& _generation
   return _currentBlock;
 }
 
-llvm::BasicBlock* VectorVisitor::initialise( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes, bool _allocatedInMemory) const
+llvm::BasicBlock* VectorVisitor::initialise( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes) const
 {
   // Don't do nothing
   return _currentBlock;
 }
 
-llvm::BasicBlock* VectorVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool _allocatedInMemory, bool /*_ignoreCount*/, bool /*_deletePointer*/ ) const
+llvm::BasicBlock* VectorVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool /*_ignoreCount*/, bool /*_deletePointer*/ ) const
 {
   // Don't do nothing
   return _currentBlock;
@@ -511,7 +502,7 @@ llvm::Constant* VectorVisitor::createStaticVariable( llvm::Module* _module, cons
     constants.push_back( visitor->createStaticVariable( _module, _type->embeddedType(), std::list<int>() ) );
   }
   GTL_ASSERT( not constants.empty());
-  return llvm::ConstantVector::get( dynamic_cast<const llvm::VectorType*>(_type->d->type(_module->getContext()) ), constants);
+  return llvm::ConstantVector::get( constants);
 }
 
 //--------- StructureVisitor ---------///
@@ -531,12 +522,12 @@ const Type* StructureVisitor::pointerToIndexType( const Type* ) const
 
 llvm::Value* StructureVisitor::pointerToValue( LLVMBackend::GenerationContext& _generationContext,
                                                 llvm::BasicBlock* _currentBlock,
-                                                llvm::Value* _pointer, int _index ) const
+                                                llvm::Value* _pointer, int _index )
 {
   std::vector<llvm::Value*> indexes;
   indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), 0));
   indexes.push_back( llvm::ConstantInt::get(llvm::Type::getInt32Ty(_generationContext.llvmContext()), _index + STRUCT_FIRST_ELEMENT ));
-  return llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "StructureVisitor::pointerToValue", _currentBlock);
+  return llvm::GetElementPtrInst::Create( _pointer, indexes, "StructureVisitor::pointerToValue", _currentBlock);
 }
 
 llvm::Value* StructureVisitor::pointerToIndex(LLVMBackend::GenerationContext& _generationContext, LLVMBackend::ExpressionGenerationContext& _expressionGenerationContext, llvm::Value* _pointer, const Type* _type, llvm::Value* _index) const
@@ -550,7 +541,7 @@ ExpressionResult StructureVisitor::get( LLVMBackend::GenerationContext& _generat
   return ExpressionResult(_pointer, _pointerType);
 }
 
-llvm::BasicBlock* StructureVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType, bool _allocatedInMemory ) const
+llvm::BasicBlock* StructureVisitor::set( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _value, const Type* _valueType) const
 {
   GTL_ASSERT( _pointerType->dataType() == Type::STRUCTURE );
   for(std::size_t i = 0; i < _pointerType->countStructDataMembers(); ++i)
@@ -560,12 +551,12 @@ llvm::BasicBlock* StructureVisitor::set( LLVMBackend::GenerationContext& _genera
     llvm::Value* nptrToValueMember = pointerToValue( _generationContext, _currentBlock, _value, i);
     const Visitor* visitor = Visitor::getVisitorFor( type );
     llvm::Value* memberValue = visitor->get( _generationContext, _currentBlock, nptrToValueMember, type ).value();
-    _currentBlock = visitor->set( _generationContext, _currentBlock, nptrToOwnMember, type, memberValue, type, _allocatedInMemory );
+    _currentBlock = visitor->set( _generationContext, _currentBlock, nptrToOwnMember, type, memberValue, type);
   }
   return _currentBlock;
 }
 
-llvm::BasicBlock* StructureVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes, bool _allocatedInMemory) const
+llvm::BasicBlock* StructureVisitor::initialise(LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, const std::list< llvm::Value*>& _sizes) const
 {
   GTL_ASSERT( _pointerType->dataType() == Type::STRUCTURE );
   
@@ -582,13 +573,13 @@ llvm::BasicBlock* StructureVisitor::initialise(LLVMBackend::GenerationContext& _
     const Visitor* visitor = Visitor::getVisitorFor( type );
     _currentBlock = visitor->initialise( _generationContext, _currentBlock,
                             pointerToValue( _generationContext, _currentBlock, _pointer, i ),
-                            type, sizes, _allocatedInMemory );
+                            type, sizes );
   }
   CodeGenerator::setCountFieldOf( _currentBlock, _pointer, CodeGenerator::integerToConstant( _generationContext.llvmContext(), INT32_C(1) ) );
   return _currentBlock;
 }
 
-llvm::BasicBlock* StructureVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool _allocatedInMemory, bool _ignoreCount, bool _deletePointer ) const
+llvm::BasicBlock* StructureVisitor::cleanUp( LLVMBackend::GenerationContext& _generationContext, llvm::BasicBlock* _currentBlock, llvm::Value* _pointer, const Type* _pointerType, llvm::Value* _donttouch, bool _ignoreCount, bool _deletePointer ) const
 {
   // TODO use ignoreCount
 #ifdef OPENGTL_ENABLE_DEBUG_OUTPUT
@@ -614,12 +605,12 @@ llvm::BasicBlock* StructureVisitor::cleanUp( LLVMBackend::GenerationContext& _ge
   {
     const Type* type = _pointerType->structDataMember(i).type();
     const Visitor* visitor = Visitor::getVisitorFor( type );
-    lastIfBlock = visitor->cleanUp( _generationContext, lastIfBlock, pointerToValue( _generationContext, lastIfBlock, _pointer, i ), type, _donttouch, _allocatedInMemory, _ignoreCount, false );
+    lastIfBlock = visitor->cleanUp( _generationContext, lastIfBlock, pointerToValue( _generationContext, lastIfBlock, _pointer, i ), type, _donttouch, _ignoreCount, false );
   }
   
   llvm::BasicBlock* afterIfBlock = llvm::BasicBlock::Create(_generationContext.llvmContext(), "afterIfBlockStructureVisitorCleanUp");
   _generationContext.llvmFunction()->getBasicBlockList().push_back( afterIfBlock);
-  if( _allocatedInMemory and _deletePointer )
+  if( _deletePointer )
   {
     CodeGenerator::freeMemory( _generationContext, _pointer, lastIfBlock );
   }
@@ -651,5 +642,5 @@ llvm::Constant* StructureVisitor::createStaticVariable( llvm::Module* _module, c
     const Visitor* visitor = Visitor::getVisitorFor( type );
     initialisers.push_back( visitor->createStaticVariable( _module, type, _type->structDataMember(i).initialSizes() ) );
   }
-  return llvm::ConstantStruct::get( dynamic_cast<const llvm::StructType*>(_type->d->type(_module->getContext())), initialisers );
+  return llvm::ConstantStruct::get( llvm::cast<llvm::StructType>(_type->d->type(_module->getContext())), initialisers );
 }
