@@ -21,6 +21,7 @@
 #define _MEMORY_MANAGER_P_H_
 
 #include <GTLCore/Export.h>
+#include <string>
 
 namespace GTLCore {
   /**
@@ -32,6 +33,7 @@ namespace GTLCore {
       struct Header;
       struct Segment;
       struct Private;
+      static const std::size_t HEADER_SIZE;
     public:
       static void* allocate(int size);
       static void desallocate(void* ptr);
@@ -39,3 +41,5 @@ namespace GTLCore {
 }
 
 #endif
+
+struct stat;
