@@ -22,7 +22,7 @@
 
 #include <GTLCore/Metadata/Entry.h>
 
-namespace OpenShiva {
+namespace GTLFragment {
   class Metadata;
 }
 
@@ -35,7 +35,7 @@ namespace GTLCore {
     class GTLCORE_EXPORT Group : public Entry {
         friend class Factory;
         friend class ParameterEntry;
-        friend class OpenShiva::Metadata;
+        friend class GTLFragment::Metadata;
         GTL_NO_COPY(Group);
         Group( const GTLCore::String& _name, const std::list< const Entry* >& _entries);
         virtual ~Group();
