@@ -30,10 +30,11 @@ namespace GTLCore {
      */
     class GTLCORE_EXPORT TextEntry : public Entry {
       friend class Factory;
+        GTL_NO_COPY(TextEntry);
         TextEntry( const GTLCore::String& _name, const GTLCore::String& _text );
         virtual ~TextEntry();
       public:
-        const GTLCore::String& text() const;
+        GTLCore::String text() const;
         virtual const TextEntry* asTextEntry() const;
       private:
         struct Private;
