@@ -22,6 +22,7 @@
 
 #include <map>
 #include <list>
+#include <GTLCore/Value.h>
 #include <GTLCore/ScopedName.h>
 #include <vector>
 
@@ -34,6 +35,7 @@ namespace GTLCore {
   class Function;
   class Parameter;
   class TypesManager;
+  class Type;
   /**
    * @internal
    * This class is not part of the public API of GTLCore.
@@ -45,14 +47,18 @@ namespace GTLCore {
       ~ModuleData();
       bool appendFunction(const ScopedName& name, Function* function);
       const std::list<Function*>* function(const String& _currentNameSpace, const String& _name) const;
-      const std::list<Function*>* function(const ScopedName& name);
+      const std::list<Function*>* function(const ScopedName& name) const;
       const GTLCore::Function* function(const GTLCore::String& _nameSpace, const GTLCore::String& name, std::vector<GTLCore::Parameter>& arguments) const;
       std::list<Function*> functions();
-      std::map< ScopedName, llvm::Constant* > constants() { return m_constants; }
-      void addConstant( const ScopedName& _scopedName, llvm::Constant* _constant )
-      {
-        m_constants[_scopedName] = _constant;
-      }
+      /**
+       * Append a constant with the given name, and of the given type.
+       */
+      bool appendConstant(const ScopedName& name, const GTLCore::Type* type, const GTLCore::Value& val);
+      /**
+       * @return all the constants of that module
+       */
+      const std::map<ScopedName, const GTLCore::Type*>& constants() const;
+      const std::map<ScopedName, GTLCore::Value>& constantsValue() const;
       void linkWith( const ModuleData* _module );
       void doLink();
       const llvm::Module* llvmModule() const { return m_llvmModule; }
@@ -60,14 +66,16 @@ namespace GTLCore {
       const llvm::Module* llvmLinkedModule() const { return m_llvmLinkedModule; }
       TypesManager* typesManager() { return m_typesManager; }
       const TypesManager* typesManager() const { return m_typesManager; }
+      void hideAllSymbolsBut(std::list<GTLCore::String> _keepVisible);
     private:
       void linkWith( const llvm::Module* _module );
     private:
+      std::map<ScopedName, const GTLCore::Type*> m_constants;
+      std::map<ScopedName, GTLCore::Value> m_constantsValue;
       llvm::Module* m_llvmModule;
       llvm::Module* m_llvmLinkedModule;
       std::map<ScopedName, std::list<Function*>* > m_functions;
       TypesManager* m_typesManager;
-      std::map< ScopedName, llvm::Constant* > m_constants;
       std::list< const llvm::Module* > m_linkModuleWith;
       std::list< GTLCore::String > m_linkModuleWithArchives;
   };
