@@ -39,6 +39,7 @@
 #include "LexerBase_p.h"
 #include "Debug.h"
 #include "Macros_p.h"
+#include "OperatorOverloadCenter_p.h"
 #include "Token_p.h"
 #include "Function_p.h"
 #include "Utils_p.h"
@@ -50,6 +51,7 @@
 #include "TypesManager.h"
 #include "TypesManager_p.h"
 #include "ModuleData_p.h"
+#include "CompilationMessages.h"
 
 using namespace GTLCore;
 
@@ -127,9 +129,8 @@ void ParserBase::parseConstantDeclaration()
           {
             reportError("Constant '" + scopedName.toString() + "' has already been declared", currentToken());
           } else {
-            AST::GlobalConstantDeclaration* gcd = new AST::GlobalConstantDeclaration( scopedName, type , expression, false );
-            variablesManager()->declareConstant( scopedName, gcd->variable() );
-            tree()->append( gcd );
+            AST::GlobalConstantDeclaration* gcd = new AST::GlobalConstantDeclaration( scopedName, type , expression, false, false );
+            appendGlobalConstantDeclaration(gcd);
           }
         }
       }
@@ -145,6 +146,20 @@ void ParserBase::parseConstantDeclaration()
   }
 }
 
+void ParserBase::appendGlobalConstantDeclaration(AST::GlobalConstantDeclaration* gcd)
+{
+  variablesManager()->declareConstant( gcd->name(), gcd->variable() );
+  tree()->append( gcd );
+  if (d->compiler)
+  {
+    ASTBackend::GenerationVisitor visitor;
+    AST::ExpressionResultSP result = gcd->initialiser()->generateValue(&visitor);
+    d->compiler->appendErrors(visitor.compilationMessages().messages());
+    const Value& val = result.scast<ASTBackend::ExpressionResult>()->value();
+    d->compiler->declareConstant(gcd->name(), gcd->type(), val);
+  }
+}
+
 void ParserBase::parseStructDefinition()
 {
   GTL_ASSERT( d->currentToken.type == Token::STRUCT );
@@ -222,11 +237,15 @@ AST::Expression* ParserBase::parseMemberArrayConstantExpression(AST::Expression*
     if( d->currentToken.type == Token::DOT )
     {
       getNextToken();
-      if( d->currentToken.type == Token::SIZE )
+      if( d->currentToken.type == Token::SIZE && _expression->type()->dataType() != Type::STRUCTURE )
       {
         return new AST::NumberExpression<gtl_int32>( compound->size() );
-      } else if( isOfType( d->currentToken, Token::IDENTIFIER ) ) {
+      } else if( d->currentToken.type == Token::SIZE || isOfType( d->currentToken, Token::IDENTIFIER ) ) {
         String name = d->currentToken.string;
+        if( d->currentToken.type == Token::SIZE )
+        {
+          name = "size";
+        }
         getNextToken();
         if( _expression->type()->dataType() == Type::STRUCTURE ) {
           idx = structMemberNameToIdx( _expression->type(), name );
@@ -244,6 +263,7 @@ AST::Expression* ParserBase::parseMemberArrayConstantExpression(AST::Expression*
       {
         ASTBackend::GenerationVisitor visitor;
         AST::ExpressionResultSP result = expr->generateValue(&visitor);
+        d->compiler->appendErrors(visitor.compilationMessages().messages());
         const Value& val = result.scast<ASTBackend::ExpressionResult>()->value();
         idx = val.asInt32();
       } else {
@@ -277,24 +297,31 @@ AST::AccessorExpression* ParserBase::parseMemberArrayExpression(AST::AccessorExp
   if( d->currentToken.type == Token::DOT )
   {
     getNextToken();
-    if( d->currentToken.type == Token::SIZE )
+    if( d->currentToken.type == Token::SIZE && _expression->type()->dataType() != Type::STRUCTURE )
     {
       getNextToken(); // eat size
       return new AST::ArraySizeAccessorExpression( _expression );
-    } else if( isOfType( d->currentToken, Token::IDENTIFIER ) ) {
+    } else if( d->currentToken.type == Token::SIZE || isOfType( d->currentToken, Token::IDENTIFIER ) ) {
       String name = d->currentToken.string;
+      if( d->currentToken.type == Token::SIZE )
+      {
+        name = "size";
+      }
       getNextToken();
       if( d->currentToken.type == Token::STARTBRACKET )
       {
         getNextToken(); // Eat the start bracket
-        const Type::StructFunctionMember* sfm = _expression->type()->d->functionMember( name );
-        if( not sfm )
+        std::vector<const Type::StructFunctionMember*> sfms = _expression->type()->d->functionMembers( name );
+        if( sfms.empty() )
         {
           reportError("Unknown member: '" + name + "' for structure " + _expression->type()->structName(), d->currentToken );
         } else {
           std::list<Function*> functions;
-          std::list<AST::Expression*> arguments = parseArguments( sfm->name() );
-          functions.push_back(const_cast<Function*>( sfm->function() ) );
+          std::list<AST::Expression*> arguments = parseArguments( name );
+          foreach(const Type::StructFunctionMember* sfm, sfms)
+          {
+            functions.push_back(const_cast<Function*>( sfm->function() ) );
+          }
           GTLCore::Function* function = 0;
           arguments = selectFunction(arguments, functions, &function, 1);
           if( not function )
@@ -302,8 +329,17 @@ AST::AccessorExpression* ParserBase::parseMemberArrayExpression(AST::AccessorExp
             delete _expression;
             return 0;
           }
-          GTL_ASSERT(function == sfm->function());
-          return new AST::FunctionMemberAccessorExpression(_expression, sfm, arguments);
+          const Type::StructFunctionMember* selectedSfm = 0;
+          foreach(const Type::StructFunctionMember* sfm, sfms)
+          {
+            if(function == sfm->function())
+            {
+              selectedSfm = sfm;
+              break;
+            }
+          }
+          GTL_ASSERT(selectedSfm);
+          return new AST::FunctionMemberAccessorExpression(_expression, selectedSfm, arguments);
         }
       } else if( _expression->type()->dataType() == Type::STRUCTURE ) {
         return parseMemberArrayExpression( new AST::StructAccessorExpression( _expression ,  structMemberNameToIdx( _expression->type(), name ) ), _constantExpression);
@@ -439,6 +475,11 @@ AST::Expression* ParserBase::parseCompoundExpression( const Type* _type, bool _c
     } else if( d->currentToken.type == endToken )
     {
       getNextToken();
+      GTL_DEBUG(*_type << " " << expressions_.size());
+      if(_type->dataType() == Type::VECTOR and _type->vectorSize() != expressions_.size())
+      {
+        reportError("Invalid number of parameters for coumpound expression.", currentToken());
+      }
       if( _constantExpression )
       {
         return new AST::ConstantCompoundExpression(_type, expressions_);
@@ -509,7 +550,7 @@ AST::Expression* ParserBase::parseExpression(bool _constantExpression, const GTL
     }
   } else if( currentToken().type == Token::STARTBRACE )
   {
-    AST::Expression* compoundExpression = parseCompoundExpression( _type, true );
+    AST::Expression* compoundExpression = parseCompoundExpression( _type, _constantExpression );
     if( compoundExpression )
     {
       return new AST::GlobalDataExpression( compoundExpression );
@@ -596,7 +637,7 @@ AST::Expression* ParserBase::parseBinaryOperator( bool _constantExpression, AST:
       } else if( d->currentToken.isUnaryOperator() ) {
         expr = parseUnaryOperator(_constantExpression);
       } else if( currentToken().type == Token::STARTBRACE ) {
-        AST::Expression* compoundExpression = parseCompoundExpression( _lhs->type() , true );
+        AST::Expression* compoundExpression = parseCompoundExpression( _lhs->type() , _constantExpression );
         if( compoundExpression )
         {
           expr = new AST::GlobalDataExpression( compoundExpression );
@@ -742,12 +783,6 @@ AST::Expression* ParserBase::parseUnaryOperator( bool _constantExpression )
   AST::Expression* expr = 0;
   if( d->currentToken.type == Token::STARTBRACKET ) {
     expr = parseExpression(_constantExpression);
-    if( not isOfType( d->currentToken, Token::ENDBRACKET ) )
-    {
-      delete expr;
-      return 0;
-    }
-    getNextToken();
   } else if( d->currentToken.isPrimary() )
   {
     expr = parsePrimaryExpression(_constantExpression);
@@ -837,7 +872,7 @@ void ParserBase::parseFunction()
   {
     Token nameToken = d->currentToken;
     ScopedName name( d->nameSpace, d->currentToken.string );
-    startParsingFunction( name.name() );
+    AST::StatementsList* initiallistofstatements = startParsingFunction( name.name() );
     getNextToken();
     // Next is start bracket
     if( isOfType( d->currentToken, Token::STARTBRACKET ) )
@@ -909,6 +944,7 @@ void ParserBase::parseFunction()
                 {
                   ASTBackend::GenerationVisitor visitor;
                   AST::ExpressionResultSP result = initialiser->generateValue(&visitor);
+                  d->compiler->appendErrors(visitor.compilationMessages().messages());
                   initialiserValue = result.scast<ASTBackend::ExpressionResult>()->value();
                   if(!initialiserValue.isValid())
                   {
@@ -939,17 +975,31 @@ void ParserBase::parseFunction()
           if( isOfType( d->currentToken, Token::STARTBRACE ) )
           {
             AST::FunctionDeclaration* fd = new AST::FunctionDeclaration( name, returnType, params );
+            if(not validateFunctionParameters(fd->function()))
+            {
+              reportError( "Invalid parameters list for function " + name.toString(), d->currentToken);
+            }
+            // Declare the function now to allow recursive call
+            bool v = d->compiler->declareFunction( name, fd->function() );
             // TODO insert functions arguments in the context
             for( unsigned int i = 0; i < params.size(); ++i)
             {
               d->variablesManager.declareParameter( ScopedName("",params[i]->parameter().name() ), fd->parametersVariable()[i] );
             }
             d->variablesManager.startContext();
-            AST::Statement* statement =appendCurrentContextGarbageCollecting(parseStatementList());
+            
+            AST::StatementsList* statementsList = parseStatementList();
+            if(initiallistofstatements)
+            {
+              AST::StatementsList* newlist = new AST::StatementsList(std::list<AST::Statement*>());
+              newlist->appendStatement(initiallistofstatements);
+              newlist->appendStatement(statementsList);
+              statementsList = newlist;
+            }
+            AST::Statement* statement =appendCurrentContextGarbageCollecting(statementsList);
             d->variablesManager.endContext();
             if( statement )
             {
-              bool v = d->compiler->declareFunction( name, fd->function() );
               if(v)
               {
                 fd->setStatement( statement );
@@ -1148,19 +1198,21 @@ AST::Statement* ParserBase::parseReturnStatement()
   GTL_ASSERT( d->currentToken.type == Token::RETURN );
   getNextToken();
   GTL_ASSERT( d->currentReturnType );
+  GTL_DEBUG("Parse return statement");
   if( d->currentReturnType->dataType() == Type::VOID  )
   {
     isOfType(d->currentToken, Token::SEMI);
     getNextToken(); // eat the coma
     return new AST::ReturnStatement( 0, d->variablesManager.garbageCollectEverything() );
   } else {
-    AST::Expression* expr = parseExpression(false);
+    AST::Expression* expr = parseExpression(false, d->currentReturnType);
     if( expr )
     {
+      GTL_DEBUG(*expr->type());
       expr = d->compiler->convertCenter()->createConvertExpression( expr, d->currentReturnType );
       if(not expr)
       {
-        reportError("Can't conert expression to return type", d->currentToken);
+        reportError("Can't convert expression to return type", d->currentToken);
       }
       if(isOfType( d->currentToken, Token::SEMI ) )
       {
@@ -1357,6 +1409,12 @@ AST::Expression* ParserBase::parsePrimaryExpression(bool _constantExpression)
         {
           if( (*it)->name().name() == d->currentToken.string )
           {
+            if( not (*it)->isConstant() )
+            {
+              reportError( "Cannot use parameter or dependant '" + (*it)->name().toString() + "' in constant expressions.", d->currentToken );                                          
+              getNextToken();
+              return 0;
+            }
             getNextToken();
             // Put the expr in a proxy to avoid double free when the AST tree is deleted
             return new AST::ProxyExpression( parseMemberArrayConstantExpression( (*it)->initialiser() ) );
@@ -1411,6 +1469,7 @@ AST::Expression* ParserBase::parsePrimaryExpression(bool _constantExpression)
             return 0;
           }
         } else {
+          GTL_ASSERT(not _constantExpression);
           VariableNG* var = d->variablesManager.getVariable( name );
           if(not var)
           {
@@ -1633,6 +1692,17 @@ void ParserBase::reportUnexpected( const Token& token )
   getNextToken();
 }
 
+Operator::Type operatorTokenToCenter(Token::Type arg1)
+{
+  switch(arg1)
+  {
+    case Token::EQUALEQUAL:
+      return Operator::Equal;
+    default:
+      return Operator::Unknown;
+  }
+}
+
 AST::Expression* ParserBase::createBinaryOperator( const Token& token, AST::Expression* lhs, AST::Expression* rhs )
 {
   if( not lhs or not rhs )
@@ -1641,6 +1711,13 @@ AST::Expression* ParserBase::createBinaryOperator( const Token& token, AST::Expr
     delete rhs;
     return 0;
   }
+  {
+    AST::BinaryExpression* overloadedExpression = 0;
+    if(d->compiler and (overloadedExpression = d->compiler->operatorOverloadCenter()->createBinaryExpression(lhs, rhs, operatorTokenToCenter(token.type)) ) )
+    {
+      return overloadedExpression;
+    }
+  }
   if( token.type == Token::EQUAL or token.type == Token::PLUSEQUAL or token.type == Token::MINUSEQUAL or token.type == Token::MULTIPLYEQUAL or token.type == Token::DIVIDEEQUAL)
   {
     rhs = d->compiler->convertCenter()->createConvertExpression( rhs, lhs->type() );
@@ -1652,7 +1729,7 @@ AST::Expression* ParserBase::createBinaryOperator( const Token& token, AST::Expr
       return 0;
     }
     AST::AccessorExpression* ve = dynamic_cast<AST::AccessorExpression*>( lhs );
-    GTL_ASSERT( rhs->type() == ve->type() );
+    GTL_ASSERT( rhs->type() == ve->type() or rhs->type()->isSameStructureLayout(ve->type()));
     if( ve )
     {
       if( token.type == Token::PLUSEQUAL )
@@ -1745,7 +1822,7 @@ AST::Expression* ParserBase::createBinaryOperator( const Token& token, AST::Expr
         return new AST::DivisionBinaryExpression( lhs, rhs );
       case Token::MODULO:
       {
-        if( lhs->type() != rhs->type() or rhs->type()  != Type::Integer32 )
+        if( lhs->type() != rhs->type() or (rhs->type()  != Type::Integer32 and rhs->type() != Type::UnsignedInteger32 ))
         {
           reportError( "'%' operator only work with integer" , token );
           delete lhs;
@@ -1792,6 +1869,7 @@ std::list<int> ParserBase::expressionsListToIntegersList( const std::list< AST::
     }
     delete *it;
   }
+  d->compiler->appendErrors(visitor.compilationMessages().messages());
   return integersList;
 }
 
@@ -1844,10 +1922,16 @@ int ParserBase::structMemberNameToIdx( const GTLCore::Type* _type, const GTLCore
   return index;
 }
 
-void ParserBase::startParsingFunction( const GTLCore::String& _name )
+AST::StatementsList* ParserBase::startParsingFunction( const GTLCore::String& _name )
 {
+  return 0;
 }
 
 void ParserBase::endParsingFunction( const GTLCore::String& _name )
 {
 }
+
+bool ParserBase::validateFunctionParameters(const Function* /*function*/)
+{
+  return true;
+}
