@@ -45,6 +45,7 @@ namespace GTLCore {
     class Statement;
     class AccessorExpression;
     class StatementsList;
+    class GlobalConstantDeclaration;
   };
   /**
    * @internal
@@ -66,6 +67,10 @@ namespace GTLCore {
     protected:
       virtual AST::Tree* tree() = 0;
     protected:
+      /**
+       * Check if the function has valid parameters.
+       */
+      virtual bool validateFunctionParameters(const Function* function);
     // Parse functions
       AST::Expression* parseExpression( bool _constantExpression, const GTLCore::Type* _type = 0 );
       AST::Expression* parseUnaryOperator( bool _constantExpression );
@@ -110,6 +115,12 @@ namespace GTLCore {
       const Type* parseFunctionType();
       void parseStructDefinition();
       void parseConstantDeclaration();
+    public:
+      /**
+       * Insert a new global constant declaration in the tree.
+       */
+      void appendGlobalConstantDeclaration(AST::GlobalConstantDeclaration* gcd);
+    protected:
       /**
        * Parse the arguments of a function.
        */
@@ -172,7 +183,7 @@ namespace GTLCore {
       TypesManager* typesManager();
       VariablesManager* variablesManager();
     protected: // Events
-      virtual void startParsingFunction( const GTLCore::String& _name );
+      virtual AST::StatementsList* startParsingFunction( const GTLCore::String& _name );
       virtual void endParsingFunction( const GTLCore::String& _name );
     private:
       int vectorMemberNameToIdx( const GTLCore::String& _name );
