@@ -19,7 +19,11 @@
 
 #include "SharedPointer.h"
 
+#ifdef LLVM_27_OR_28
 #include <llvm/System/Atomic.h>
+#else
+#include <llvm/Support/Atomic.h>
+#endif
 
 #include "Debug.h"
 
