@@ -28,7 +28,7 @@ namespace GTLCore
   inline GTLCore::String extractDir( const GTLCore::String& filename )
   {
     int end = filename.length() - 1;
-    while( filename[end] != '/' and filename[end] != '\\'  and end >= 0 ) --end;
+    while( end >= 0 and filename[end] != '/' and filename[end] != '\\' ) --end;
     
     if(end < 0) return "";
     return filename.substr( 0, end + 1);
