@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2007 Cyrille Berger <cberger@cberger.net>
+ *  Copyright (c) 2007,2008,2009,2010 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -61,6 +61,8 @@ namespace GTLCore {
        * This class defines a member of a structure.
        */
       class GTLCORE_EXPORT StructDataMember {
+        public:
+          class GTLCORE_EXPORT Information;
         public:
           /**
            * @param _name the name of the member
@@ -70,8 +72,8 @@ namespace GTLCore {
            *                      it should be set to -1 if the type is not an array)
            * @param _pointer set to true if this struct member is a pointer
            */
-          StructDataMember(const GTLCore::String& _name, const Type* _type);
-          StructDataMember(const GTLCore::String& _name, const Type* _type, const std::list<int>& _initialSizes);
+          StructDataMember(const GTLCore::String& _name, const Type* _type, Information* infor = 0);
+          StructDataMember(const GTLCore::String& _name, const Type* _type, const std::list<int>& _initialSizes, Information* infor = 0);
           StructDataMember(const StructDataMember& rhs);
           StructDataMember& operator=(const StructDataMember& rhs);
           ~StructDataMember();
@@ -87,6 +89,7 @@ namespace GTLCore {
            * @return the initial size of the member.
            */
           const std::list<int>& initialSizes() const;
+          const Information* information() const;
         private:
           void deref();
           struct Private;
@@ -177,6 +180,10 @@ namespace GTLCore {
        * @return true if the type is a structure (aka if dataType() == STRUCTURE)
        */
       bool isStructure() const;
+      /**
+       * @return true if the this type and @p type have the same structure layout
+       */
+      bool isSameStructureLayout(const GTLCore::Type* type) const;
     public:
       struct Private;
       Private* const d;
