@@ -1,5 +1,5 @@
  /*
- *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
+ *  Copyright (c) 2008,2009,2010 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 #ifndef _GTLCore_TYPE_P_H_
 #define _GTLCore_TYPE_P_H_
 
+#include "Debug.h"
 #include "Type.h"
 #include "Parameter.h"
 namespace llvm {
@@ -34,6 +35,32 @@ namespace LLVMBackend {
 
 namespace GTLCore {
   class Function;
+  /**
+   * @internal
+   * @ingroup GTLCore
+   */
+  class GTLCORE_EXPORT Type::StructDataMember::Information {
+    public:
+      /**
+       * @param setter is the name of a function that will take a pointer
+       *               to the structure as first parameter, and the value
+       *               as second parameter, and that will be called in operation=
+       *               to change the value.
+       */
+      Information(Function* _setter) : m_setter(_setter) {
+      }
+      ~Information();
+      const Function* setter() const {
+        return m_setter;
+      }
+      void setSetter(Function* function)
+      {
+        GTL_ASSERT(m_setter == 0);
+        m_setter = function;
+      }
+    private:
+      Function* m_setter;
+  };
   /**
    * @internal
    * @ingroup GTLCore
@@ -106,23 +133,23 @@ namespace GTLCore {
       Private() : structDataMembers(0), structFunctionMembers(0), structPrivateFunctionMembers(0), m_visitor(0), m_factory(0) {}
       Private( Type::DataType _dataType );
       ~Private();
-      const llvm::Type * type(llvm::LLVMContext& _context) const;
+      llvm::Type * type(llvm::LLVMContext& _context) const;
       /**
        * @return a pointer version of the type a.k.a. llvm::PointerType::get( type(), 0)
        */
-      const llvm::Type * pointerType(llvm::LLVMContext& _context) const;
+      llvm::Type * pointerType(llvm::LLVMContext& _context) const;
       /**
        * @return how the type will be used as function argument (usually return type(),
        *         except for ARRAY and STRUCTURE where it return pointerType() )
        */
-      const llvm::Type * asArgumentType(llvm::LLVMContext& _context) const;
+      llvm::Type * asArgumentType(llvm::LLVMContext& _context) const;
       void addFunctionMember( const StructFunctionMember& );
       void addPrivateFunctionMember( const StructFunctionMember& );
       int memberToIndex(const GTLCore::String&);
       /**
        * @return the function member associated with that name, or null if none
        */
-      const Type::StructFunctionMember* functionMember( const GTLCore::String&) const;
+      std::vector<const Type::StructFunctionMember*> functionMembers( const GTLCore::String& _name) const;
       /**
        * @return the private function member associated with that name, or null if none
        */
@@ -157,8 +184,8 @@ namespace GTLCore {
       const GTLCore::Type* subtypeAt( unsigned int _index );
       const GTLCore::String& symbolName() const;
       static const GTLCore::Type* createArbitraryType( AribtraryTypeFactory* _factory);
-      static std::vector<const llvm::Type*> createFunctionParams(llvm::LLVMContext& _context, const Function* function);
-      static const llvm::FunctionType* createFunctionFunctionType(llvm::LLVMContext& _context, const Function* function);
+      static std::vector< llvm::Type*> createFunctionParams(llvm::LLVMContext& _context, const Function* function);
+      llvm::FunctionType* createFunctionFunctionType(llvm::LLVMContext& _context, const GTLCore::Function* function);
       static void deleteTypes();
     private:
       DataType dataType;
