@@ -84,8 +84,6 @@ const GTLCore::Type* TypesManager::getVector( const GTLCore::Type* _type, int _s
 {
   GTL_ASSERT( _type );
   GTL_ASSERT( _size > 0 );
-  std::map< const GTLCore::Type*, std::map< int, const GTLCore::Type* > >::const_iterator it
-      = TypesManager::Private::knownVectors.find( _type );
   const GTLCore::Type*& type = TypesManager::Private::knownVectors[ _type ][ _size ];
   if( type == 0 )
   {
