@@ -23,6 +23,24 @@
 
 using namespace GTLCore;
 
+void TypesManager::Private::deleteStaticMaps()
+{
+  for( std::map< const GTLCore::Type*, const GTLCore::Type*>::iterator it = TypesManager::Private::knownArrays.begin();
+       it != TypesManager::Private::knownArrays.end(); ++it)
+  {
+    delete it->second;
+  }
+  for( std::map< const GTLCore::Type*, std::map< int, const GTLCore::Type* > >::iterator it = TypesManager::Private::knownVectors.begin();
+       it != TypesManager::Private::knownVectors.end(); ++it)
+  {
+    for( std::map< int, const GTLCore::Type* >::iterator it2 = it->second.begin();
+         it2 != it->second.end(); ++it2 )
+    {
+      delete it2->second;
+    }
+  }
+}
+
 bool TypesManager::Private::isKnownType(const GTLCore::String& _name) const
 {
   return knownTypes.find(_name) != knownTypes.end();
@@ -33,7 +51,7 @@ const GTLCore::Type* TypesManager::Private::createStructure( const GTLCore::Stri
   GTL_DEBUG("createStructure " << _name);
   if(isKnownType( _name) )
   {
-    GTL_DEBUG("Allready exist");
+    GTL_DEBUG("Already exist");
     return 0;
   }
   GTLCore::Type* t = new GTLCore::Type( _name, _members);
