@@ -98,14 +98,6 @@ namespace GTLCore {
        * @return the pointer for this variable
        */
       llvm::Value* pointer(llvm::BasicBlock* _currentBlock);
-      /**
-       * @return true if the variable is allocated in memory, false otherwise
-       */
-      bool allocatedInMemory() const;
-      /**
-       * Make the variable allocated in memory if the type is structure or array
-       */
-      void setAllocatedInMemory( bool _allocated );
       /**
        * @return true if the pointer is constant (which means it can't be replaced)
        */
