@@ -24,10 +24,11 @@
 #include <llvm/Module.h>
 #include <llvm/DerivedTypes.h>
 #include <llvm/Target/TargetOptions.h>
-#include <llvm/Target/TargetSelect.h>
 #include <llvm/LLVMContext.h>
 #include <llvm/Support/CommandLine.h>
-#include <llvm/System/Threading.h>
+#include <llvm/Support/Threading.h>
+#include <llvm/Support/ErrorHandling.h>
+#include <llvm/Support/TargetSelect.h>
 
 #include "Function_p.h"
 #include "Value.h"
@@ -47,9 +48,22 @@ struct VirtualMachine::Private {
 VirtualMachine* VirtualMachine::Private::virtualMachine = 0;
 int VirtualMachine::Private::optimLevel = 2;
 
+void gtl_llvm_error_handler(void *user_data, const std::string& reason)
+{
+  GTL_ABORT(reason);
+}
+
+
 VirtualMachine::VirtualMachine() : d(new Private)
 {
   d->executionEngine = 0;
+  
+#ifdef LLVM_27
+  llvm::llvm_install_error_handler(&gtl_llvm_error_handler);
+#else
+  llvm::install_fatal_error_handler(&gtl_llvm_error_handler);
+#endif
+  
   llvm::llvm_start_multithreaded();
 
   std::string errorMessage;
@@ -83,7 +97,9 @@ VirtualMachine::VirtualMachine() : d(new Private)
 VirtualMachine::~VirtualMachine()
 {
   llvm::llvm_stop_multithreaded();
+#ifndef LLVM_27_OR_28
   delete d->executionEngine;
+#endif
   delete d;
 }
 
@@ -127,9 +143,9 @@ void *VirtualMachine::getPointerToFunction(Function *F)
   return getPointerToFunction( F->d->data->function( ) );
 }
 
-void* VirtualMachine::getGlobalVariablePointer( llvm::GlobalVariable* GV)
+void* VirtualMachine::getGlobalVariablePointer( const llvm::GlobalVariable* _pointer)
 {
-    return d->executionEngine->getPointerToGlobal( GV );
+    return d->executionEngine->getPointerToGlobal( _pointer );
 }
 
 #if 0
