@@ -69,7 +69,7 @@ namespace GTLCore {
        * @return a pointer to the function
        */
       void *getPointerToFunction(Function *F);
-      void* getGlobalVariablePointer( llvm::GlobalVariable* _pointer);
+      void* getGlobalVariablePointer(const llvm::GlobalVariable* _pointer);
 #if 0
       /**
        * Set the value of a global variable.
