@@ -31,10 +31,10 @@ GTLCORE_EXPORT void gtl_free( void* _data );
 }
 
 template<class T>
-T* gtlAllocate(int elt = 1)
+T* gtlAllocate()
 {
-  T* t = (T*)gtl_malloc( elt * sizeof(T) );
-  // t.count = 1;
+  T* t = (T*)gtl_malloc( sizeof(T) );
+  t->count = 0;
   return t;
 }
 
