@@ -53,7 +53,7 @@ inline ArrayWrap* gtlAllocateArray( int _size )
 {
   ArrayWrap* arrayWrap = gtlAllocate<ArrayWrap>( );
   arrayWrap->size = _size;
-  arrayWrap->data = gtlAllocate<_T_>( _size );
+  arrayWrap->data = gtl_malloc( _size * sizeof(_T_) );
   return arrayWrap;
 }
 
