@@ -21,7 +21,11 @@
 
 #include <algorithm>
 
+#ifdef LLVM_27_OR_28
 #include <llvm/System/Path.h>
+#else
+#include <llvm/Support/Path.h>
+#endif
 
 #include <GTLCore/String.h>
 
