@@ -57,7 +57,7 @@ int CodeGenerator::s_evaluatePixelsId = 0;
 llvm::Function* CodeGenerator::createMemCpyFunction( llvm::Module* _module )
 {
   // TODO that stuff was copied from a llvmgcc output, can't we use memcpy intrinsinc ?
-  std::vector<const llvm::Type*> memcpyTyArgs;
+  std::vector<llvm::Type*> memcpyTyArgs;
   memcpyTyArgs.push_back(llvm::PointerType::get(llvm::Type::getInt8Ty(_module->getContext()), 0));
   memcpyTyArgs.push_back(llvm::PointerType::get(llvm::Type::getInt8Ty(_module->getContext()), 0));
   memcpyTyArgs.push_back(llvm::Type::getInt32Ty(_module->getContext()));
@@ -86,7 +86,7 @@ llvm::Value* CodeGenerator::accessPixelAlphaPos( LLVMBackend::GenerationContext&
   std::vector<llvm::Value*> indexes;
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(PixelWrap::POS_ALPHAPOS) ));
-  return llvm::GetElementPtrInst::Create( _pixel, indexes.begin(), indexes.end(), "", _currentBlock );
+  return llvm::GetElementPtrInst::Create( _pixel, indexes, "", _currentBlock );
 }
 
 llvm::Value* CodeGenerator::accessPixelDataPtr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel)
@@ -95,7 +95,16 @@ llvm::Value* CodeGenerator::accessPixelDataPtr( LLVMBackend::GenerationContext&
   std::vector<llvm::Value*> indexes;
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(PixelWrap::POS_DATA) ));
-  return llvm::GetElementPtrInst::Create( _pixel, indexes.begin(), indexes.end(), "", _currentBlock );
+  return llvm::GetElementPtrInst::Create( _pixel, indexes, "", _currentBlock );
+}
+
+llvm::Value* CodeGenerator::accessColorConverterPtr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel)
+{
+  SHIVA_DEBUG( *_pixel );
+  std::vector<llvm::Value*> indexes;
+  indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
+  indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(PixelWrap::POS_CONVERTER) ));
+  return llvm::GetElementPtrInst::Create( _pixel, indexes, "", _currentBlock );
 }
 
 llvm::Value* CodeGenerator::accessPixelDataAsU8Ptr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel)
@@ -126,13 +135,13 @@ llvm::Value* CodeGenerator::callMemcpy( LLVMBackend::GenerationContext& _gc, llv
   memcpy_params.push_back( _n );
   memcpy_params.push_back( LLVMBackend::CodeGenerator::integerToConstant( _gc.llvmContext(), INT32_C(1) ) );
   llvm::CallInst* callMemCpy = llvm::CallInst::Create(
-                  func_llvm_memcpy_i32, memcpy_params.begin(), memcpy_params.end(), "", _currentBlock);
+                  func_llvm_memcpy_i32, memcpy_params, "", _currentBlock);
   callMemCpy->setCallingConv(llvm::CallingConv::C);
   callMemCpy->setTailCall( false );
   return callMemCpy;
 }
 
-llvm::BasicBlock* CodeGenerator::memToPixel( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _dataPointer, llvm::Value* _pixel, llvm::Value* _image )
+llvm::BasicBlock* CodeGenerator::memToPixel( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _dataPointer, llvm::Value* _pixel, const GTLCore::Type* _imageType, llvm::Value* _image )
 {
   // Access to the data pointer for the _pixel
   llvm::Value* _pointerToPixelVector = accessPixelDataPtr( _gc, _currentBlock, _pixel );
@@ -141,6 +150,11 @@ llvm::BasicBlock* CodeGenerator::memToPixel( LLVMBackend::GenerationContext& _gc
   arguments.push_back( _pointerToPixelVector );
   arguments.push_back( _dataPointer );
   callVirtualMember( _gc, _currentBlock, _image, ImageWrap::INDEX_MEM_TO_VEC, arguments);
+
+  llvm::Value* _pointerToColorConverter = accessColorConverterPtr( _gc, _currentBlock, _pixel );
+  
+  new llvm::StoreInst(callImageColorConverter(_gc, _currentBlock, _imageType, _image), _pointerToColorConverter, "CodeGenerator::memToPixel", _currentBlock);
+  
   
   return _currentBlock;
 }
@@ -163,7 +177,7 @@ void CodeGenerator::setPixelCoordinates( LLVMBackend::GenerationContext& _gc, ll
 {
   SHIVA_DEBUG("setPixelCoordinates");
   // Create the coord vector
-  llvm::Value* result = LLVMBackend::CodeGenerator::createVector( 2, LLVMBackend::CodeGenerator::floatToConstant( _gc.llvmContext(), 0.0 ),  GTLCore::Type::Float32 );
+  llvm::Value* result = LLVMBackend::CodeGenerator::createVector( 2, LLVMBackend::CodeGenerator::floatToConstant( _gc.llvmContext(), 0.0 ) );
   SHIVA_DEBUG(*result << " " << *_iVal << " " << *_jVal);
   result = llvm::InsertElementInst::Create( result, LLVMBackend::CodeGenerator::convertValueTo( _currentBlock, _iVal, _iValType, GTLCore::Type::Float32), LLVMBackend::CodeGenerator::integerToConstant(_gc.llvmContext(), INT32_C(0)), "", _currentBlock );
   result = llvm::InsertElementInst::Create( result, LLVMBackend::CodeGenerator::convertValueTo( _currentBlock, _jVal, _jValType, GTLCore::Type::Float32), LLVMBackend::CodeGenerator::integerToConstant(_gc.llvmContext(), INT32_C(1)), "", _currentBlock );
@@ -171,7 +185,7 @@ void CodeGenerator::setPixelCoordinates( LLVMBackend::GenerationContext& _gc, ll
   std::vector<llvm::Value*> indexes;
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(PixelWrap::POS_COORD) ));
-  llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pixel, indexes.begin(), indexes.end(), "", _currentBlock );
+  llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pixel, indexes, "", _currentBlock );
   SHIVA_DEBUG( *_pixel << " " << *ptr << " " << *result);
   new llvm::StoreInst( result, ptr, "", _currentBlock );
 }
@@ -185,7 +199,7 @@ void CodeGenerator::setPixelAlphaPos( LLVMBackend::GenerationContext& _gc, llvm:
   std::vector<llvm::Value*> indexes;
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), INT32_C(0)));
   indexes.push_back( _gc.codeGenerator()->integerToConstant(_gc.llvmContext(), gtl_int32(PixelWrap::POS_ALPHAPOS) ));
-  llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pixel, indexes.begin(), indexes.end(), "", _currentBlock );
+  llvm::Value* ptr = llvm::GetElementPtrInst::Create( _pixel, indexes, "", _currentBlock );
   
   // Store the alpha position
   new llvm::StoreInst( alphaPos, ptr, "", _currentBlock );
@@ -233,7 +247,7 @@ llvm::Function* CodeGenerator::generateEvaluatePixels( Kernel* _kernel, llvm::Mo
   llvm::LLVMContext& context = moduleData->llvmModule()->getContext();
   
   // Create the function
-  std::vector<const llvm::Type*> params;
+  std::vector<llvm::Type*> params;
   params.push_back( llvm::Type::getInt32Ty(context) ); // int x
   params.push_back( llvm::Type::getInt32Ty(context) ); // int y
   params.push_back( llvm::Type::getInt32Ty(context) ); // int width
@@ -286,6 +300,11 @@ llvm::Function* CodeGenerator::generateEvaluatePixels( Kernel* _kernel, llvm::Mo
   // Create the pixel
     GTLCore::VariableNG* resultVar = new GTLCore::VariableNG( _kernel->d->outputPixelType(), false, false );
     resultVar->initialise( generationContext, initialBlock, LLVMBackend::ExpressionResult(), std::list<llvm::Value*>());
+    llvm::Value* _pointerToColorConverter = accessColorConverterPtr( generationContext, initialBlock, resultVar->pointer(initialBlock) );
+  
+    new llvm::StoreInst(callImageColorConverter(generationContext, initialBlock, _kernel->d->outputImageType(), arg_result), _pointerToColorConverter, "CodeGenerator::memToPixel", initialBlock);
+  
+  
   // Get the evaluatePixel function
     const std::list<GTLCore::Function*>* ePFunctions = moduleData->function( _kernel->name(), "evaluatePixel" );
     SHIVA_ASSERT( ePFunctions );
@@ -336,7 +355,7 @@ llvm::Function* CodeGenerator::generateEvaluatePixels( Kernel* _kernel, llvm::Mo
         llvm::Value* iVal_transformed = LLVMBackend::CodeGenerator::convertValueTo(firstBlockILoop,
                                                 iVal_int, GTLCore::Type::Integer32, GTLCore::Type::Float32 );
         
-        std::vector<const llvm::Type*> transfoArgs;
+        std::vector<llvm::Type*> transfoArgs;
         transfoArgs.push_back(llvm::PointerType::get(llvm::Type::getInt8Ty(context), 0));
         transfoArgs.push_back(llvm::Type::getFloatTy(context));
         transfoArgs.push_back(llvm::Type::getFloatTy(context));
@@ -354,7 +373,7 @@ llvm::Function* CodeGenerator::generateEvaluatePixels( Kernel* _kernel, llvm::Mo
         transfo_params.push_back( jVal_transformed );
         transfo_params.push_back( iValBuffer );
         transfo_params.push_back( jValBuffer );
-        llvm::CallInst *CallFunc = llvm::CallInst::Create(func_transform_map, transfo_params.begin(), transfo_params.end(), "", firstBlockILoop);
+        llvm::CallInst *CallFunc = llvm::CallInst::Create(func_transform_map, transfo_params, "", firstBlockILoop);
         CallFunc->setTailCall(false);
         
         iVal_transformed = new llvm::LoadInst(iValBuffer, "", firstBlockILoop);
@@ -382,7 +401,7 @@ llvm::Function* CodeGenerator::generateEvaluatePixels( Kernel* _kernel, llvm::Mo
         SHIVA_ASSERT( llvmEPFunction );
         SHIVA_DEBUG( evaluatePixel_params.size() );
         GTL_COMPARE_FUNCTION_PARAMETERS( llvmEPFunction, evaluatePixel_params );
-        llvm::CallInst::Create( llvmEPFunction, evaluatePixel_params.begin(), evaluatePixel_params.end(), "", firstBlockILoop );
+        llvm::CallInst::Create( llvmEPFunction, evaluatePixel_params, "", firstBlockILoop );
         
         // Synchronize the output pixel with input
         // Call image_wrap_data on the result to get the pointer on destination data
@@ -674,10 +693,10 @@ llvm::Value* CodeGenerator::callVirtualMember( LLVMBackend::GenerationContext& _
   indexes.push_back( _gc.codeGenerator()->integerToConstant( _gc.llvmContext(), gtl_int32(_member_index + STRUCT_FIRST_ELEMENT)));
   GTL_DEBUG( "Call " << _member_index << " on " << *_pointer );
   
-  llvm::Value* funcPtr = new llvm::LoadInst( llvm::GetElementPtrInst::Create( _pointer, indexes.begin(), indexes.end(), "", _currentBlock ), "" , _currentBlock);
+  llvm::Value* funcPtr = new llvm::LoadInst( llvm::GetElementPtrInst::Create( _pointer, indexes, "", _currentBlock ), "" , _currentBlock);
   GTL_DEBUG( *funcPtr );
   GTL_COMPARE_FUNCTION_PARAMETERS( funcPtr, _arguments );
-  return llvm::CallInst::Create( funcPtr, _arguments.begin(), _arguments.end(), "", _currentBlock );
+  return llvm::CallInst::Create( funcPtr, _arguments, "", _currentBlock );
 }
 
 llvm::Value* CodeGenerator::callImageWrapData( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap, llvm::Value* _x, llvm::Value* _y, bool callConst )
@@ -701,7 +720,7 @@ llvm::Value* CodeGenerator::callImageWrapData( LLVMBackend::GenerationContext& _
   GTL_COMPARE_FUNCTION_PARAMETERS( func, image_wrap_data_params );
   
   return llvm::CallInst::Create(
-      func, image_wrap_data_params.begin(), image_wrap_data_params.end(), "", _currentBlock );
+      func, image_wrap_data_params, "", _currentBlock );
 }
 
 llvm::Value* CodeGenerator::callImageAlphaPos( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap )
@@ -715,7 +734,20 @@ llvm::Value* CodeGenerator::callImageAlphaPos( LLVMBackend::GenerationContext& _
   GTL_COMPARE_FUNCTION_PARAMETERS( func, image_wrap_data_params );
   
   return llvm::CallInst::Create(
-      func, image_wrap_data_params.begin(), image_wrap_data_params.end(), "", _currentBlock );
+      func, image_wrap_data_params, "", _currentBlock );
+}
+
+llvm::Value* CodeGenerator::callImageColorConverter( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap )
+{
+  GTL_ASSERT(_imageType);
+  std::vector<llvm::Value*> params;
+  params.push_back(_imageWrap);
+  
+  llvm::Function* func = Wrapper::image_color_converter( _gc.llvmModule(), _imageType );
+  GTL_COMPARE_FUNCTION_PARAMETERS( func, params );
+  
+  return llvm::CallInst::Create(
+      func, params, "", _currentBlock );  
 }
 
 int imageSampleNearestId = 0;
@@ -764,7 +796,7 @@ llvm::Function* CodeGenerator::generateImageSampleNearest(GTLCore::ModuleData* _
   //    memToPixel( image, px, image_wrap_data(self, x, y ) );
     currentBlock = memToPixel( generationContext, currentBlock,
                                callImageWrapData( generationContext, currentBlock, _imageType, arg_self, x_i, y_i, true ),
-                               px_var, arg_self );
+                               px_var, _imageType, arg_self );
     setPixelCoordinates( generationContext, currentBlock, px_var, x_f, GTLCore::Type::Float32, y_f, GTLCore::Type::Float32 );
     setPixelAlphaPos( generationContext, currentBlock, px_var, arg_self, _imageType );
     llvm::ReturnInst::Create( context, px_var, currentBlock);
@@ -882,3 +914,35 @@ llvm::Function* CodeGenerator::generatePixelAlpha( GTLCore::ModuleData* _moduleD
     LLVMBackend::CodeGenerator::createIfStatement(firstBlock, compar, GTLCore::Type::Boolean, noAlphaPosBlock, noAlphaPosBlock, alphaPosBlock);
   return func;
 }
+
+llvm::Function* CodeGenerator::createWrapConvertColorToPixelFunction( LLVMBackend::GenerationContext& _gc, llvm::Type* _pixelType )
+{
+  std::vector<llvm::Type*> tyArgs;
+  tyArgs.push_back( GTLCore::Type::Pointer->d->type(_gc.llvmContext()) );
+  tyArgs.push_back( GTLCore::Type::Float32->d->pointerType(_gc.llvmContext()) );
+  tyArgs.push_back( _pixelType );
+  tyArgs.push_back( GTLCore::Type::Integer32->d->type(_gc.llvmContext()) );
+    
+  llvm::FunctionType* ty = llvm::FunctionType::get( llvm::Type::getVoidTy(_gc.llvmContext()), tyArgs, false);
+  
+  llvm::Function* func = (llvm::Function*)_gc.llvmModule()->getOrInsertFunction(
+      "wrapConvertColorToPixel", ty); // (external, no body)
+  func->setCallingConv(llvm::CallingConv::C);
+  return func;
+}
+
+llvm::Function* CodeGenerator::createWrapConvertPixelToColorFunction( LLVMBackend::GenerationContext& _gc, llvm::Type* _pixelType )
+{
+  std::vector<llvm::Type*> tyArgs;
+  tyArgs.push_back( GTLCore::Type::Pointer->d->type(_gc.llvmContext()) );
+  tyArgs.push_back( _pixelType );
+  tyArgs.push_back( GTLCore::Type::Float32->d->pointerType(_gc.llvmContext()) );
+  tyArgs.push_back( GTLCore::Type::Integer32->d->type(_gc.llvmContext()) );
+    
+  llvm::FunctionType* ty = llvm::FunctionType::get( llvm::Type::getVoidTy(_gc.llvmContext()), tyArgs, false);
+  
+  llvm::Function* func = (llvm::Function*)_gc.llvmModule()->getOrInsertFunction(
+      "wrapConvertPixelToColor", ty); // (external, no body)
+  func->setCallingConv(llvm::CallingConv::C);
+  return func;
+}
