@@ -28,6 +28,7 @@ namespace llvm {
   class Function;
   class Module;
   class Value;
+  class Type;
 }
 
 namespace GTLCore {
@@ -53,9 +54,9 @@ namespace OpenShiva {
       /**
        * Copy a pixel from memory to the vector.
        */
-      static llvm::BasicBlock* memToPixel( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _dataPointer, llvm::Value* _pixel, llvm::Value* _image );
+      static llvm::BasicBlock* memToPixel( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _dataPointer, llvm::Value* _pixel, const GTLCore::Type* _imageType, llvm::Value* _image );
       static llvm::BasicBlock* pixelToMem( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel, llvm::Value* _dataPointer, llvm::Value* _image, llvm::Value* channelsFlags );
-      static llvm::Function* generateEvaluatePixels( Kernel* _kernel, llvm::Module* _module, int _channels );
+      static llvm::Function* generateEvaluatePixels( OpenShiva::Kernel* _kernel, llvm::Module* _module, int _channels );
       static llvm::Function* generateMemToVec( GTLCore::ModuleData* _moduleData, llvm::Module* _module, const GTLCore::PixelDescription& _pixelDescription );
       static llvm::Function* generateVecToMem( GTLCore::ModuleData* _moduleData, llvm::Module* _module, const GTLCore::PixelDescription& _pixelDescription );
       /**
@@ -74,10 +75,17 @@ namespace OpenShiva {
        * @return a pointer to the data pointer of a pixel (as a pointer to a vector of float)
        */
       static llvm::Value* accessPixelDataPtr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel);
+      /**
+       * @return a pointer to the data pointer of a pixel (as a pointer to a vector of float)
+       */
+      static llvm::Value* accessColorConverterPtr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel);
       /**
        * @return a pointer to the data pointer of a pixel cast to a (float*)
        */
       static llvm::Value* accessPixelDataAsF32Ptr( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel);
+    public:
+      static llvm::Function* createWrapConvertColorToPixelFunction( LLVMBackend::GenerationContext& _gc, llvm::Type* _pixelType );
+      static llvm::Function* createWrapConvertPixelToColorFunction( LLVMBackend::GenerationContext& _gc, llvm::Type* _pixelType );
     private:
       static llvm::Value* accessPixelAlphaPos( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, llvm::Value* _pixel);
       static llvm::Function* createMemCpyFunction( llvm::Module* _module );
@@ -95,6 +103,7 @@ namespace OpenShiva {
        */
       static llvm::Value* callImageWrapData( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap, llvm::Value* _x, llvm::Value* _y, bool callConst);
       static llvm::Value* callImageAlphaPos( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap);
+      static llvm::Value* callImageColorConverter( LLVMBackend::GenerationContext& _gc, llvm::BasicBlock* _currentBlock, const GTLCore::Type* _imageType, llvm::Value* _imageWrap );
     private:
       static int s_evaluatePixelsId;
   };
