@@ -81,6 +81,14 @@ namespace OpenShiva {
        * Set a given parameter to a given value
        */
       void setParameter( const GTLCore::String& _name, const GTLCore::Value& );
+      /**
+       * Set a given parameter to a given value
+       */
+      void setParameter( size_t _id, const GTLCore::Value& _value );
+      /**
+       * @return the id of a parameter
+       */
+      std::size_t parameterId( const GTLCore::String& _name );
       /**
        * Set a list of parameters
        */
