@@ -25,7 +25,7 @@
 #include "GTLCore/Value.h"
 
 #include <list>
-#include "LibraryCompilation_p.h"
+#include "GTLFragment/LibraryCompilation_p.h"
 
 namespace llvm {
   class Function;
@@ -43,7 +43,7 @@ namespace OpenShiva {
    *
    * Internal data of @ref Kernel
    */
-  class KernelPrivate : public LibraryCompilation {
+  class KernelPrivate : public GTLFragment::LibraryCompilation {
     friend class Kernel;
       KernelPrivate();
       virtual ~KernelPrivate();
@@ -51,6 +51,9 @@ namespace OpenShiva {
       virtual void preCompilation();
       virtual void cleanup();
       virtual void postCompilation();
+      virtual void createWrapper(GTLCore::ModuleData* _moduleData, llvm::Module* module, int _channels, GTLFragment::WhichStdLibrary _library);
+      virtual GTLFragment::Wrapper* wrapper();
+      virtual void addOperatorOverloads(GTLCore::OperatorOverloadCenter* _center);
     public:
       const std::list< const GTLCore::Type* >& inputsTypes();
       const GTLCore::Type* outputPixelType();
@@ -61,9 +64,10 @@ namespace OpenShiva {
        * Determines output and input types.
        */
       void determineTypes();
+      void runEvaluateDependentsIfNeeded();
+      bool needRunEvealuateDependents;
       Kernel* self;
       llvm::Function* evaluatePixelsFunction;
-      Wrapper* wrapper;
       std::list< const GTLCore::Type* > m_inputsTypes;
       const GTLCore::Type* m_outputPixelType;
       const GTLCore::Type* m_outputImageType;
