@@ -20,19 +20,19 @@
 #include "LightParser_p.h"
 
 #include "Debug.h"
-#include "Lexer_p.h"
+#include "GTLFragment/Lexer_p.h"
 
 using namespace OpenShiva;
 
 struct LightParser::Private {
-  Lexer* lexer;
+  GTLFragment::Lexer* lexer;
   GTLCore::String name;
   Source::SourceType sourceType;
   Source::ImageType outputImageType;
   std::vector<Source::ImageType> inputImageTypes;
 };
 
-LightParser::LightParser( Lexer* lexer ) : ParserBase(0, lexer), d(new Private)
+LightParser::LightParser( GTLFragment::Lexer* lexer ) : ParserBase(0, lexer), d(new Private)
 {
   d->lexer = lexer;
 }
@@ -210,7 +210,7 @@ void LightParser::eatLoopOf( GTLCore::Token::Type start, GTLCore::Token::Type en
   } while( count > 0 and currentToken().type != GTLCore::Token::END_OF_FILE  );
 }
 
-const GTLCore::String& LightParser::name() const
+GTLCore::String LightParser::name() const
 {
   return d->name;
 }
