@@ -20,7 +20,11 @@
 #include "SourcesCollection.h"
 
 // LLVM
+#ifdef LLVM_27_OR_28
 #include <llvm/System/Path.h>
+#else
+#include <llvm/Support/Path.h>
+#endif
 
 #include "GTLCore/String.h"
 #include "GTLCore/Macros_p.h"
@@ -93,3 +97,15 @@ std::list< Source > SourcesCollection::sources(Source::SourceType _source) const
   }
   return sources;
 }
+
+Source SourcesCollection::source(const GTLCore::String& _string) const
+{
+  foreach(Source source,d->kernels)
+  {
+    if(source.name() == _string)
+    {
+      return source;
+    }
+  }
+  return Source();
+}
