@@ -58,6 +58,10 @@ namespace OpenShiva {
        * @return the list of sources in the collection that have the type given in argument.
        */
       std::list< Source > sources(Source::SourceType _source) const;
+      /**
+       * @return a kernel by the name of @p _string or null if no such kernel exists
+       */
+      Source source(const GTLCore::String& _string) const;
     private:
       struct Private;
       Private* const d;
