@@ -135,6 +135,8 @@ void Wrapper::fillTypesManager( GTLCore::TypesManager* _typesManager, GTLCore::C
     moduleData()->linkWith( library->data() );
     addFunctionFromModuleToType(regionType, library, GTLCore::ScopedName("wrappers", "translate"));
     addFunctionFromModuleToType(regionType, library, GTLCore::ScopedName("wrappers", "translated"));
+    addFunctionFromModuleToType(regionType, library, GTLCore::ScopedName("wrappers", "topLeft"));
+    addFunctionFromModuleToType(regionType, library, GTLCore::ScopedName("wrappers", "bottomRight"));
   }
 }
 
