@@ -21,6 +21,7 @@
 #define _OPENSHIVA_WRAPPER_P_H_
 
 #include "GTLCore/Type_p.h"
+#include <GTLFragment/Wrapper_p.h>
 
 struct ImageWrap;
 
@@ -47,21 +48,23 @@ namespace OpenShiva {
    * region.
    * @ingroup OpenShiva
    */
-  class Wrapper {
+  class Wrapper : public GTLFragment::Wrapper {
       class Mem2VecFloatTypeAribtraryTypeFactory;
       class VecFloat2MemTypeAribtraryTypeFactory;
+      GTL_NO_COPY(Wrapper)
     public:
-      Wrapper(Kernel* _kernel, GTLCore::ModuleData* _moduleData, llvm::Module* module);
+      Wrapper(Kernel* _kernel, GTLCore::ModuleData* _moduleData, llvm::Module* module, int _channels, bool loadShivaWrapper);
       ~Wrapper();
       ImageWrap* wrapImage(GTLCore::AbstractImage* _abstractImage);
     private:
       struct Private;
       Private* const d;
     public:
-      static void fillTypesManager( GTLCore::ModuleData* _module, llvm::Module* llvmModule, GTLCore::TypesManager*, GTLCore::ConvertCenter*, int _channels );
+      virtual void fillTypesManager( GTLCore::TypesManager*, GTLCore::ConvertCenter*);
       static llvm::Function* image_wrap_dataFunction( llvm::Module* _module, const GTLCore::Type* _imageType );
       static llvm::Function* image_wrap_const_dataFunction( llvm::Module* _module, const GTLCore::Type* _imageType );
       static llvm::Function* image_alpha_posFunction( llvm::Module* _module, const GTLCore::Type* _imageType );
+      static llvm::Function* image_color_converter( llvm::Module* _module, const GTLCore::Type* _imageType );
       static llvm::FunctionType* image_wrap_sample_nearest_type( llvm::LLVMContext& context, GTLCore::TypesManager* _typesManager, const GTLCore::Type* _imageType, const GTLCore::Type* _pixelType );
       static llvm::FunctionType* image_wrap_mem_to_vec_float_type( llvm::LLVMContext& context, GTLCore::TypesManager* _typesManager, int _channels );
       static llvm::FunctionType* image_wrap_vec_float_to_mem_type( llvm::LLVMContext& context, GTLCore::TypesManager* _typesManager, int _channels );
@@ -72,7 +75,7 @@ namespace OpenShiva {
        */
       static const GTLCore::Type* vectorType( GTLCore::TypesManager* _typesManager, int _channels );
     private:
-      static void createRegionType( GTLCore::ModuleData* _module, llvm::Module* _llvmModule, GTLCore::TypesManager* _typesManager );
+      static const GTLCore::Type* createRegionType( GTLCore::ModuleData* _module, llvm::Module* _llvmModule, GTLCore::TypesManager* _typesManager );
       static const GTLCore::Type* createPixelType( GTLCore::ModuleData* _module, llvm::Module* llvmModule, GTLCore::TypesManager* _typesManager, GTLCore::ConvertCenter* _convertCenter, const GTLCore::String& _suffix, int _channels );
       static void createImageType( GTLCore::ModuleData* _moduleData, llvm::Module* _llvmModule, GTLCore::TypesManager* _typesManager, const GTLCore::String& _suffix, int _channels, const GTLCore::Type* _pixelType );
   };
