@@ -24,6 +24,7 @@
 #include "OpenShiva/Export.h"
 
 namespace GTLCore {
+  class AbstractColorConverter;
   class AbstractImage;
 }
 
@@ -75,6 +76,12 @@ extern "C" {
    * @return the alpha position of an image
    */
   OPENSHIVA_EXPORT int image_alpha_pos( ImageWrap* _imageWrap );
+  /**
+   * @internal
+   * @ingroup OpenShiva
+   * @return the color converter of an image
+   */
+  OPENSHIVA_EXPORT const GTLCore::AbstractColorConverter* image_color_converter( ImageWrap* _imageWrap );
 }
 
 #endif
