@@ -18,16 +18,18 @@
  */
 
 #include "GTLCore/ProgressReport.h"
+#include "GTLCore/Type.h"
 
 class TestProgressReport : public GTLCore::ProgressReport {
   public:
-    TestProgressReport() : m_row(0), m_pixel(0)
+    TestProgressReport(bool interrupted) : m_row(0), m_pixel(0), m_interrupted(interrupted)
     {
     }
     void nextRow() { ++m_row; }
     void nextPixel() { ++m_pixel; }
-    bool interrupted() const { return false; }
+    bool interrupted() const { return m_interrupted; }
     int m_row, m_pixel;
+    bool m_interrupted;
 };
 
 class TestKernelProgressReport : public GTLTest::Case {
@@ -47,10 +49,14 @@ class TestKernelProgressReport : public GTLTest::Case {
 }" );
       k.compile();
       GTLTEST_CHECK_REQUIRED(k.isCompiled());
-      TestProgressReport tpr;
+      TestProgressReport tpr(false);
       GTLCore::Image img(100, 50, GTLCore::PixelDescription(GTLCore::Type::Integer8, 4));
       k.evaluatePixels( GTLCore::RegionI(0,0,100,50), std::list< const GTLCore::AbstractImage* >(), &img, &tpr);
       GTLTEST_CHECK_EQUAL(tpr.m_pixel, 5000);
       GTLTEST_CHECK_EQUAL(tpr.m_row, 50);
+      TestProgressReport tpr2(true);
+      k.evaluatePixels( GTLCore::RegionI(0,0,100,50), std::list< const GTLCore::AbstractImage* >(), &img, &tpr2);
+      GTLTEST_CHECK_EQUAL(tpr2.m_pixel, 1);
+      GTLTEST_CHECK_EQUAL(tpr2.m_row, 0);
     }
 };
