@@ -24,9 +24,6 @@
 
 using namespace GTLCore;
 
-#include "TestLexer.h"
-#include "TestMetadataLexer.h"
-#include "TestMetadataParser.h"
 #include "TestSource.h"
 #include "TestWrapper.h"
 #include "TestKernelThreading.h"
@@ -34,9 +31,6 @@ using namespace GTLCore;
 #include "TestKernelChannel.h"
 
 GTLTEST_MAIN_BEGIN(TestOpenShiva)
-GTLTEST_MAIN_ADD_CASE(TestLexer)
-GTLTEST_MAIN_ADD_CASE(TestMetadataLexer )
-GTLTEST_MAIN_ADD_CASE(TestMetadataParser)
 GTLTEST_MAIN_ADD_CASE(TestSource)
 GTLTEST_MAIN_ADD_CASE(TestWrapper)
 #ifdef GTLTEST_HAVE_THREAD
