@@ -24,6 +24,14 @@ class TestSource : public GTLTest::Case {
     TestSource() : GTLTest::Case("Source") {}
     virtual void runTest()
     {
+      {
+        OpenShiva::Source source;
+        GTLTEST_CHECK_EQUAL( source.source(), "" );
+        GTLTEST_CHECK_EQUAL( source.name(), "" );
+        GTLTEST_CHECK_EQUAL( source.metadataCompilationMessages().errors().size(), 0 );
+        GTLTEST_CHECK_EQUAL( source.sourceType(), OpenShiva::Source::InvalidSource );
+        GTLTEST_CHECK_EQUAL( source.outputImageType(), OpenShiva::Source::InvalidImage );        
+      }
       {
         GTLCore::String sourceCodeGenerator = "\
   kernel myGenerator { \
@@ -39,6 +47,14 @@ class TestSource : public GTLTest::Case {
         GTLTEST_CHECK_EQUAL( sourceGenerator.outputImageType(), OpenShiva::Source::Image );
         GTLTEST_CHECK_EQUAL( sourceGenerator.countInputImages(), 0 );
         GTLTEST_CHECK_EQUAL( sourceGenerator.inputImageType(0), OpenShiva::Source::InvalidImage );
+        OpenShiva::Source copy(sourceGenerator);
+        GTLTEST_CHECK_EQUAL( copy.source(), sourceCodeGenerator );
+        GTLTEST_CHECK_EQUAL( copy.name(), "myGenerator" );
+        GTLTEST_CHECK_EQUAL( copy.metadataCompilationMessages().errors().size(), 0 );
+        GTLTEST_CHECK_EQUAL( copy.sourceType(), OpenShiva::Source::GeneratorKernel );
+        GTLTEST_CHECK_EQUAL( copy.outputImageType(), OpenShiva::Source::Image );
+        GTLTEST_CHECK_EQUAL( copy.countInputImages(), 0 );
+        GTLTEST_CHECK_EQUAL( copy.inputImageType(0), OpenShiva::Source::InvalidImage );
       }
       {
         GTLCore::String sourceCodeFilter = "\
